@@ -1,7 +1,7 @@
 /* StarPU --- Runtime system for heterogeneous multicore architectures.
  *
- * Copyright (C) 2009-2023  Université de Bordeaux, CNRS (LaBRI UMR 5800), Inria
- * Copyright (C) 2013       Thibaut Lambert
+ * Copyright (C) 2009-2025  University of Bordeaux, CNRS (LaBRI UMR 5800), Inria
+ * Copyright (C) 2013-2013  Thibaut Lambert
  *
  * StarPU is free software; you can redistribute it and/or modify
  * it under the terms of the GNU Lesser General Public License as published by
@@ -69,6 +69,7 @@ static struct starpu_task * create_task_potrf(unsigned k, unsigned nblocks)
 #if defined(STARPU_USE_CUDA) && defined(STARPU_HAVE_LIBCUSOLVER)
 	/* Temporary data to save libcusolver from allocating/deallocating memory */
 	task->handles[1] = scratch;
+	task->handles[2] = devInfo;
 #endif
 
 	/* this is an important task */
@@ -290,7 +291,7 @@ int main(int argc, char **argv)
 	}
 
 #ifndef STARPU_SIMGRID
-	/* create a simple definite positive symetric matrix example
+	/* create a simple definite positive symmetric matrix example
 	 *
 	 *	Hilbert matrix : h(i,j) = 1/(i+j+1) (+ n In to make is stable)
 	 * */
