@@ -1,6 +1,6 @@
 /* StarPU --- Runtime system for heterogeneous multicore architectures.
  *
- * Copyright (C) 2009-2021  Université de Bordeaux, CNRS (LaBRI UMR 5800), Inria
+ * Copyright (C) 2009-2025  University of Bordeaux, CNRS (LaBRI UMR 5800), Inria
  *
  * StarPU is free software; you can redistribute it and/or modify
  * it under the terms of the GNU Lesser General Public License as published by
@@ -31,6 +31,9 @@
 #define CUBLAS_SWAP	cublasCswap
 #define CUBLAS_IAMAX	cublasIcamax
 
+#define CUSOLVER_GETRF  cusolverDnCgetrf
+#define CUSOLVER_GETRF_BUFFERSIZE cusolverDnCgetrf_bufferSize
+
 #define CPU_GEMM	CGEMM
 #define CPU_TRSM	CTRSM
 #define CPU_SCAL	CSCAL
