@@ -1,7 +1,7 @@
 /* StarPU --- Runtime system for heterogeneous multicore architectures.
  *
- * Copyright (C) 2010-2021  Université de Bordeaux, CNRS (LaBRI UMR 5800), Inria
- * Copyright (C) 2010       Mehdi Juhoor
+ * Copyright (C) 2010-2025  University of Bordeaux, CNRS (LaBRI UMR 5800), Inria
+ * Copyright (C) 2010-2010  Mehdi Juhoor
  *
  * StarPU is free software; you can redistribute it and/or modify
  * it under the terms of the GNU Lesser General Public License as published by
@@ -19,77 +19,83 @@
 
 #include "xlu.h"
 #include "xlu_kernels.h"
+#include "starpu_cusolver.h"
 
-static int create_task_11(starpu_data_handle_t dataA, unsigned k, unsigned no_prio)
+static int create_task_getrf(starpu_data_handle_t dataA, unsigned k, unsigned no_prio, int nblocks)
 {
 	int ret;
 	struct starpu_task *task = starpu_task_create();
-	task->cl = &cl11;
+	task->cl = &cl_getrf;
 
 	/* which sub-data is manipulated ? */
 	task->handles[0] = starpu_data_get_sub_data(dataA, 2, k, k);
 
-	task->tag_id = TAG11(k);
+#if defined(STARPU_USE_CUDA) && defined(STARPU_HAVE_LIBCUSOLVER)
+	task->handles[1] = scratch;
+	task->handles[2] = devInfo;
+#endif
+
+	task->tag_id = TAG_GETRF(k);
 	task->color = 0xffff00;
 
 	/* this is an important task */
 	if (!no_prio)
-		task->priority = STARPU_MAX_PRIO;
+		task->priority = 3*nblocks - 3*k; /* Bottom-level-based prio */
 
 	ret = starpu_task_submit(task);
 	if (ret != -ENODEV) STARPU_CHECK_RETURN_VALUE(ret, "starpu_task_submit");
 	return ret;
 }
 
-static int create_task_12(starpu_data_handle_t dataA, unsigned k, unsigned j, unsigned no_prio)
+static int create_task_trsm_ll(starpu_data_handle_t dataA, unsigned k, unsigned j, unsigned no_prio, int nblocks)
 {
 	int ret;
 	struct starpu_task *task = starpu_task_create();
-	task->cl = &cl12;
+	task->cl = &cl_trsm_ll;
 
 	/* which sub-data is manipulated ? */
 	task->handles[0] = starpu_data_get_sub_data(dataA, 2, k, k);
 	task->handles[1] = starpu_data_get_sub_data(dataA, 2, j, k);
 
-	task->tag_id = TAG12(k,j);
+	task->tag_id = TAG_TRSM_LL(k,j);
 	task->color = 0x8080ff;
 
-	if (!no_prio && (j == k+1))
-		task->priority = STARPU_MAX_PRIO;
+	if (!no_prio)
+		task->priority = 3*nblocks - (2*k + j); /* Bottom-level-based prio */
 
 	ret = starpu_task_submit(task);
 	if (ret != -ENODEV) STARPU_CHECK_RETURN_VALUE(ret, "starpu_task_submit");
 	return ret;
 }
 
-static int create_task_21(starpu_data_handle_t dataA, unsigned k, unsigned i, unsigned no_prio)
+static int create_task_trsm_ru(starpu_data_handle_t dataA, unsigned k, unsigned i, unsigned no_prio, int nblocks)
 {
 	int ret;
 	struct starpu_task *task = starpu_task_create();
 
-	task->cl = &cl21;
+	task->cl = &cl_trsm_ru;
 
 	/* which sub-data is manipulated ? */
 	task->handles[0] = starpu_data_get_sub_data(dataA, 2, k, k);
 	task->handles[1] = starpu_data_get_sub_data(dataA, 2, k, i);
 
-	task->tag_id = TAG21(k,i);
+	task->tag_id = TAG_TRSM_RU(k,i);
 	task->color = 0x8080c0;
 
-	if (!no_prio && (i == k+1))
-		task->priority = STARPU_MAX_PRIO;
+	if (!no_prio)
+		task->priority = 3*nblocks - (2*k + i); /* Bottom-level-based prio */
 
 	ret = starpu_task_submit(task);
 	if (ret != -ENODEV) STARPU_CHECK_RETURN_VALUE(ret, "starpu_task_submit");
 	return ret;
 }
 
-static int create_task_22(starpu_data_handle_t dataA, unsigned k, unsigned i, unsigned j, unsigned no_prio)
+static int create_task_gemm(starpu_data_handle_t dataA, unsigned k, unsigned i, unsigned j, unsigned no_prio, int nblocks)
 {
 	int ret;
 	struct starpu_task *task = starpu_task_create();
 
-	task->cl = &cl22;
+	task->cl = &cl_gemm;
 	task->color = 0x00ff00;
 
 	/* which sub-data is manipulated ? */
@@ -97,10 +103,10 @@ static int create_task_22(starpu_data_handle_t dataA, unsigned k, unsigned i, un
 	task->handles[1] = starpu_data_get_sub_data(dataA, 2, j, k);
 	task->handles[2] = starpu_data_get_sub_data(dataA, 2, j, i);
 
-	task->tag_id = TAG22(k,i,j);
+	task->tag_id = TAG_GEMM(k,i,j);
 
-	if (!no_prio &&  (i == k + 1) && (j == k +1) )
-		task->priority = STARPU_MAX_PRIO;
+	if (!no_prio)
+		task->priority = 3*nblocks - (k + i + j); /* Bottom-level-based prio */
 
 	ret = starpu_task_submit(task);
 	if (ret != -ENODEV) STARPU_CHECK_RETURN_VALUE(ret, "starpu_task_submit");
@@ -130,14 +136,14 @@ static int dw_codelet_facto_v3(starpu_data_handle_t dataA, unsigned nblocks, uns
 
 		starpu_iteration_push(k);
 
-		ret = create_task_11(dataA, k, no_prio);
+		ret = create_task_getrf(dataA, k, no_prio, nblocks);
 		if (ret == -ENODEV) return ret;
 
 		for (i = k+1; i<nblocks; i++)
 		{
-			ret = create_task_12(dataA, k, i, no_prio);
+			ret = create_task_trsm_ll(dataA, k, i, no_prio, nblocks);
 		     if (ret == -ENODEV) return ret;
-		     ret = create_task_21(dataA, k, i, no_prio);
+		     ret = create_task_trsm_ru(dataA, k, i, no_prio, nblocks);
 		     if (ret == -ENODEV) return ret;
 		}
 		starpu_data_wont_use(starpu_data_get_sub_data(dataA, 2, k, k));
@@ -145,7 +151,7 @@ static int dw_codelet_facto_v3(starpu_data_handle_t dataA, unsigned nblocks, uns
 		for (i = k+1; i<nblocks; i++)
 		     for (j = k+1; j<nblocks; j++)
 		     {
-			     ret = create_task_22(dataA, k, i, j, no_prio);
+			     ret = create_task_gemm(dataA, k, i, j, no_prio, nblocks);
 			  if (ret == -ENODEV) return ret;
 		     }
 		for (i = k+1; i<nblocks; i++)
@@ -206,8 +212,12 @@ int STARPU_LU(lu_decomposition)(TYPE *matA, unsigned size, unsigned ld, unsigned
 
 	starpu_data_map_filters(dataA, 2, &f, &f2);
 
+	lu_kernel_init(size / nblocks);
+
 	int ret = dw_codelet_facto_v3(dataA, nblocks, no_prio);
 
+	lu_kernel_fini();
+
 	/* gather all the data */
 	starpu_data_unpartition(dataA, STARPU_MAIN_RAM);
 	starpu_data_unregister(dataA);
