@@ -1,7 +1,7 @@
 ! StarPU --- Runtime system for heterogeneous multicore architectures.
 !
-! Copyright (C) 2015-2020  Université de Bordeaux, CNRS (LaBRI UMR 5800), Inria
-! Copyright (C) 2015       ONERA
+! Copyright (C) 2015-2025   University of Bordeaux, CNRS (LaBRI UMR 5800), Inria
+! Copyright (C) 2015-2015   ONERA
 !
 ! StarPU is free software; you can redistribute it and/or modify
 ! it under the terms of the GNU Lesser General Public License as published by
@@ -32,9 +32,11 @@ PROGRAM f90_example
   TYPE(type_mesh_elt),POINTER    :: elt   => NULL()
   INTEGER(KIND=C_INT)            :: i,Nelt,res,cpus
   INTEGER(KIND=C_INT)            :: starpu_maj,starpu_min,starpu_rev
-  INTEGER(KIND=C_INT)            :: neq,ng,nb,it,it_tot
-  REAL(KIND=C_DOUBLE)            :: r, coeff2
+  INTEGER(KIND=C_INT)            :: it,it_tot
+  INTEGER(KIND=C_INT), PARAMETER :: loop_color = INT(Z'7FFF00', KIND=C_INT)
+  INTEGER(KIND=C_INT), PARAMETER :: copy_color = INT(Z'3F7FFF', KIND=C_INT)
   REAL(KIND=C_DOUBLE),TARGET     :: flops
+  INTEGER(C_INT), TARGET         :: max_prio
 
   TYPE(C_PTR) :: cl_loop_element = C_NULL_PTR ! loop codelet
   TYPE(C_PTR) :: cl_copy_element = C_NULL_PTR ! copy codelet
@@ -67,6 +69,7 @@ PROGRAM f90_example
      CALL fstarpu_shutdown()
      STOP 77
   END IF
+  max_prio = fstarpu_sched_get_max_priority()
 
   cl_loop_element = fstarpu_codelet_allocate()
   CALL fstarpu_codelet_add_cpu_func(cl_loop_element, C_FUNLOC(loop_element_cpu_fortran))
@@ -74,12 +77,14 @@ PROGRAM f90_example
   CALL fstarpu_codelet_add_buffer(cl_loop_element, FSTARPU_RW)
   CALL fstarpu_codelet_add_buffer(cl_loop_element, FSTARPU_R)
   CALL fstarpu_codelet_set_name(cl_loop_element, C_CHAR_"LOOP_ELEMENT"//C_NULL_CHAR)
+  CALL fstarpu_codelet_set_color(cl_loop_element, loop_color)
 
   cl_copy_element = fstarpu_codelet_allocate()
   CALL fstarpu_codelet_add_cpu_func(cl_copy_element, C_FUNLOC(copy_element_cpu_fortran))
   CALL fstarpu_codelet_add_buffer(cl_copy_element, FSTARPU_RW)
   CALL fstarpu_codelet_add_buffer(cl_copy_element, FSTARPU_R)
   CALL fstarpu_codelet_set_name(cl_copy_element, C_CHAR_"COPY_ELEMENT"//C_NULL_CHAR)
+  CALL fstarpu_codelet_set_color(cl_copy_element, copy_color)
 
   !Registration of elements
   DO i = 1,Nelt
@@ -95,12 +100,13 @@ PROGRAM f90_example
      DO i = 1,Nelt
         elt => mesh%elt(i)
         flops = elt%Ng * ( (elt%Np * numpar%Neq_max * 2) + 1 + elt%Np * numpar%Neq_max)
-        CALL fstarpu_insert_task((/ cl_loop_element,    &
+        CALL fstarpu_task_insert((/ cl_loop_element,    &
                 FSTARPU_VALUE, c_loc(numpar%coeff), FSTARPU_SZ_C_DOUBLE, &
                 FSTARPU_R, elt%ro_h,                 &
                 FSTARPU_RW, elt%dro_h,                &
                 FSTARPU_R, elt%basis_h,              &
                 FSTARPU_FLOPS, c_loc(flops),         &
+                FSTARPU_PRIORITY, c_loc(FSTARPU_DEFAULT_PRIO),         &
                 C_NULL_PTR /))
      ENDDO
      ! sync (if needed by the algorithm)
@@ -111,9 +117,10 @@ PROGRAM f90_example
      ! copy dro to ro for each element
      DO i = 1,Nelt
         elt => mesh%elt(i)
-        CALL fstarpu_insert_task((/ cl_copy_element,    &
+        CALL fstarpu_task_insert((/ cl_copy_element,    &
                 FSTARPU_RW, elt%ro_h,                 &
                 FSTARPU_R, elt%dro_h,                &
+                FSTARPU_PRIORITY, c_loc(max_prio),         &
                 C_NULL_PTR /))
      ENDDO
      ! sync (if needed by the algorithm)
