@@ -1,7 +1,6 @@
 /* StarPU --- Runtime system for heterogeneous multicore architectures.
  *
- * Copyright (C) 2009, 2010, 2012  Université de Bordeaux 1
- * Copyright (C) 2010, 2011, 2012  Centre National de la Recherche Scientifique
+ * Copyright (C) 2009-2025  University of Bordeaux, CNRS (LaBRI UMR 5800), Inria
  *
  * StarPU is free software; you can redistribute it and/or modify
  * it under the terms of the GNU Lesser General Public License as published by
@@ -25,19 +24,12 @@
 #include <string.h>
 #include <math.h>
 #include <sys/types.h>
-#include <pthread.h>
 #include <signal.h>
 
 #include <starpu.h>
 
-#ifdef STARPU_USE_GORDON
-#include <gordon/null.h>
-#endif
-
-#define FPRINTF(ofile, fmt, args ...) do { if (!getenv("STARPU_SSILENT")) {fprintf(ofile, fmt, ##args); }} while(0)
-#define TAG(i, iter)	((starpu_tag_t)  (((uint64_t)iter)<<32 | (i)) )
-
-struct starpu_codelet cl = {};
+#define FPRINTF(ofile, fmt, ...) do { if (!getenv("STARPU_SSILENT")) {fprintf(ofile, fmt, ## __VA_ARGS__); }} while(0)
+#define TAG(i, iter)	((starpu_tag_t)  (((uint64_t)iter)<<32 | (i)))
 
 #define Ni	64
 #define Nk	256
@@ -70,27 +62,28 @@ static void parse_args(int argc, char **argv)
 
 void callback_cpu(void *argcb);
 
-static void tag_cleanup_grid(unsigned ni, unsigned iter)
+static void tag_cleanup_grid(unsigned iter)
 {
 	unsigned i;
 
 	for (i = 0; i < ni; i++)
 		starpu_tag_remove(TAG(i,iter));
-} 
+}
 
 static int create_task_grid(unsigned iter)
 {
-	int i;
-	int ret;
+	unsigned i;
 
 /*	FPRINTF(stderr, "start iter %d ni %d...\n", iter, ni); */
 
 	for (i = 0; i < ni; i++)
 	{
+		int ret;
+
 		/* create a new task */
 		struct starpu_task *task = starpu_task_create();
 
-		task->cl = &cl;
+		task->cl = &starpu_codelet_nop;
 		task->cl_arg = NULL;
 
 		task->use_tag = 1;
@@ -106,11 +99,7 @@ static int create_task_grid(unsigned iter)
 	return 0;
 }
 
-void cpu_codelet(void *descr[] __attribute__ ((unused)), void *_args __attribute__ ((unused)))
-{
-}
-
-int main(int argc __attribute__((unused)) , char **argv __attribute__((unused)))
+int main(int argc , char **argv)
 {
 	unsigned i;
 	int ret;
@@ -120,26 +109,13 @@ int main(int argc __attribute__((unused)) , char **argv __attribute__((unused)))
 		exit(77);
 	STARPU_CHECK_RETURN_VALUE(ret, "starpu_init");
 
-#ifdef STARPU_SLOW_MACHINE
+#ifdef STARPU_QUICK_CHECK
 	ni /= 4;
 	nk /= 16;
 #endif
 
-#ifdef STARPU_USE_GORDON
-	/* load an empty kernel and get its identifier */
-	unsigned gordon_null_kernel = load_gordon_null_kernel();
-#endif
-
 	parse_args(argc, argv);
 
-	cl.cpu_funcs[0] = cpu_codelet;
-	cl.cuda_funcs[0] = cpu_codelet;
-	cl.opencl_funcs[0] = cpu_codelet;
-#ifdef STARPU_USE_GORDON
-	cl.gordon_func = gordon_null_kernel;
-#endif
-	cl.nbuffers = 0;
-
 	FPRINTF(stderr, "ITER : %u\n", nk);
 
 	for (i = 0; i < nk; i++)
@@ -151,13 +127,13 @@ int main(int argc __attribute__((unused)) , char **argv __attribute__((unused)))
 
 		/* cleanup old grids ... */
 		if (i > 1)
-			tag_cleanup_grid(ni, i-1);
+			tag_cleanup_grid(i-1);
 	}
 
 	starpu_task_wait_for_all();
 
 enodev:
-	tag_cleanup_grid(ni, nk-1);
+	tag_cleanup_grid(nk-1);
 
 	starpu_shutdown();
 
