@@ -1,6 +1,6 @@
 /* StarPU --- Runtime system for heterogeneous multicore architectures.
  *
- * Copyright (C) 2014-2021  Université de Bordeaux, CNRS (LaBRI UMR 5800), Inria
+ * Copyright (C) 2014-2025  University of Bordeaux, CNRS (LaBRI UMR 5800), Inria
  *
  * StarPU is free software; you can redistribute it and/or modify
  * it under the terms of the GNU Lesser General Public License as published by
@@ -21,7 +21,7 @@
 
 /**
    @defgroup API_OpenMP_Runtime_Support OpenMP Runtime Support
-   @brief This section describes the interface provided for implementing OpenMP runtimes on top of StarPU.
+   @brief API for implementing OpenMP runtimes on top of StarPU.
    @{
 */
 
@@ -35,7 +35,10 @@
    \sa starpu_omp_unset_lock()
    \sa starpu_omp_test_lock()
 */
-typedef struct { void *internal; /**< opaque pointer for internal use */ } starpu_omp_lock_t;
+typedef struct
+{
+	void *internal; /**< opaque pointer for internal use */
+} starpu_omp_lock_t;
 
 /**
    Opaque Nestable Lock object (\anchor NestableLock) for inter-task
@@ -46,7 +49,10 @@ typedef struct { void *internal; /**< opaque pointer for internal use */ } starp
    \sa starpu_omp_unset_nest_lock()
    \sa starpu_omp_test_nest_lock()
 */
-typedef struct { void *internal; /**< opaque pointer for internal use */  } starpu_omp_nest_lock_t;
+typedef struct
+{
+	void *internal; /**< opaque pointer for internal use */
+} starpu_omp_nest_lock_t;
 
 /**
    Set of constants for selecting the for loop iteration scheduling
@@ -61,11 +67,11 @@ typedef struct { void *internal; /**< opaque pointer for internal use */  } star
 enum starpu_omp_sched_value
 {
 	starpu_omp_sched_undefined = 0, /**< Undefined iteration scheduling algorithm. */
-	starpu_omp_sched_static    = 1, /**< \b Static iteration scheduling algorithm.*/
+	starpu_omp_sched_static	   = 1, /**< \b Static iteration scheduling algorithm.*/
 	starpu_omp_sched_dynamic   = 2, /**< \b Dynamic iteration scheduling algorithm.*/
-	starpu_omp_sched_guided    = 3, /**< \b Guided iteration scheduling algorithm.*/
-	starpu_omp_sched_auto      = 4, /**< \b Automatically choosen iteration scheduling algorithm.*/
-	starpu_omp_sched_runtime   = 5 /**< Choice of iteration scheduling algorithm deferred at \b runtime.*/
+	starpu_omp_sched_guided	   = 3, /**< \b Guided iteration scheduling algorithm.*/
+	starpu_omp_sched_auto	   = 4, /**< \b Automatically chosen iteration scheduling algorithm.*/
+	starpu_omp_sched_runtime   = 5	/**< Choice of iteration scheduling algorithm deferred at \b runtime.*/
 };
 
 /**
@@ -75,12 +81,12 @@ enum starpu_omp_sched_value
 */
 enum starpu_omp_proc_bind_value
 {
-	starpu_omp_proc_bind_undefined  = -1, /**< Undefined processor binding method.*/
-	starpu_omp_proc_bind_false  = 0,      /**< Team threads may be moved between places at any time.*/
-	starpu_omp_proc_bind_true   = 1,      /**< Team threads may not be moved between places.*/
-	starpu_omp_proc_bind_master = 2,      /**< Assign every thread in the team to the same place as the \b master thread.*/
-	starpu_omp_proc_bind_close  = 3,      /**< Assign every thread in the team to a place \b close to the parent thread.*/
-	starpu_omp_proc_bind_spread = 4       /**< Assign team threads as a sparse distribution over the selected places.*/
+	starpu_omp_proc_bind_undefined = -1, /**< Undefined processor binding method.*/
+	starpu_omp_proc_bind_false     = 0,  /**< Team threads may be moved between places at any time.*/
+	starpu_omp_proc_bind_true      = 1,  /**< Team threads may not be moved between places.*/
+	starpu_omp_proc_bind_master    = 2,  /**< Assign every thread in the team to the same place as the \b master thread.*/
+	starpu_omp_proc_bind_close     = 3,  /**< Assign every thread in the team to a place \b close to the parent thread.*/
+	starpu_omp_proc_bind_spread    = 4   /**< Assign team threads as a sparse distribution over the selected places.*/
 };
 
 /**
@@ -94,27 +100,27 @@ struct starpu_omp_parallel_region_attr
 	   parallel region implicit tasks. The codelet must provide a
 	   CPU implementation function.
 	*/
-	struct starpu_codelet  cl;
+	struct starpu_codelet cl;
 	/**
 	   Array of zero or more ::starpu_data_handle_t data handle to
 	   be passed to the parallel region implicit tasks.
 	*/
-	starpu_data_handle_t  *handles;
+	starpu_data_handle_t *handles;
 	/**
 	   Optional pointer to an inline argument to be passed to the
 	   region implicit tasks.
 	*/
-	void     *cl_arg;
+	void *cl_arg;
 	/**
 	   Size of the optional inline argument to be passed to the
 	   region implicit tasks, or 0 if unused.
 	*/
-	size_t    cl_arg_size;
+	size_t cl_arg_size;
 	/**
 	    Boolean indicating whether the optional inline argument
 	    should be automatically freed (true), or not (false).
 	*/
-	unsigned  cl_arg_free;
+	unsigned cl_arg_free;
 
 	/**
 	   Boolean indicating whether the \b if clause of the
@@ -145,28 +151,28 @@ struct starpu_omp_task_region_attr
 	   CPU implementation function or an accelerator
 	   implementation for offloaded target regions.
 	*/
-	struct starpu_codelet  cl;
+	struct starpu_codelet cl;
 	/**
 	   Array of zero or more ::starpu_data_handle_t data handle to
 	   be passed to the task region explicit tasks.
 	*/
-	starpu_data_handle_t  *handles;
+	starpu_data_handle_t *handles;
 	/**
 	   Optional pointer to an inline argument to be passed to the
 	   region implicit tasks.
 	*/
-	void     *cl_arg;
+	void *cl_arg;
 	/**
 	   Size of the optional inline argument to be passed to the
 	   region implicit tasks, or 0 if unused.
 	*/
-	size_t    cl_arg_size;
+	size_t cl_arg_size;
 	/**
 	   Boolean indicating whether the optional inline argument
 	   should be automatically freed (true), or not (false).
 	*/
-	unsigned  cl_arg_free;
-	int       priority;
+	unsigned cl_arg_free;
+	int priority;
 
 	/**
 	   Boolean indicating whether the \b if clause of the
@@ -206,9 +212,8 @@ struct starpu_omp_task_region_attr
 };
 
 #ifdef __cplusplus
-extern "C"
-{
-#define __STARPU_OMP_NOTHROW throw ()
+extern "C" {
+#define __STARPU_OMP_NOTHROW throw()
 #else
 #define __STARPU_OMP_NOTHROW __attribute__((__nothrow__))
 #endif
@@ -219,11 +224,11 @@ extern "C"
 */
 
 /**
-   Initialize StarPU and its OpenMP Runtime support.
+   Initialize StarPU and its OpenMP Runtime support. See \ref OMPInitExit for more details.
 */
 extern int starpu_omp_init(void) __STARPU_OMP_NOTHROW;
 /**
-   Shutdown StarPU and its OpenMP Runtime support.
+   Shutdown StarPU and its OpenMP Runtime support. See \ref OMPInitExit for more details.
 */
 extern void starpu_omp_shutdown(void) __STARPU_OMP_NOTHROW;
 
@@ -242,6 +247,7 @@ extern void starpu_omp_shutdown(void) __STARPU_OMP_NOTHROW;
    generated parallel region is nested within the generating parallel region.
 
    This function can be used to implement <c>\#pragma omp parallel</c>.
+   See \ref OMPParallel for more details.
 */
 extern void starpu_omp_parallel_region(const struct starpu_omp_parallel_region_attr *attr) __STARPU_OMP_NOTHROW;
 
@@ -252,6 +258,7 @@ extern void starpu_omp_parallel_region(const struct starpu_omp_parallel_region_a
    f is the function to be called. \p arg is an argument passed to function \p f.
 
    This function can be used to implement <c>\#pragma omp master</c>.
+   See \ref OMPSingle for more details.
 */
 extern void starpu_omp_master(void (*f)(void *arg), void *arg) __STARPU_OMP_NOTHROW;
 
@@ -263,6 +270,7 @@ extern void starpu_omp_master(void (*f)(void *arg), void *arg) __STARPU_OMP_NOTH
    outlining.
    \return <c>!0</c> if called by the region's master thread.
    \return <c>0</c> if not called by the region's master thread.
+   See \ref OMPSingle for more details.
 */
 extern int starpu_omp_master_inline(void) __STARPU_OMP_NOTHROW;
 
@@ -280,6 +288,7 @@ extern int starpu_omp_master_inline(void) __STARPU_OMP_NOTHROW;
    completed its execution.
 
    This function can be used to implement <c>\#pragma omp barrier</c>.
+   See \ref OMPBarrier for more details.
 */
 extern void starpu_omp_barrier(void) __STARPU_OMP_NOTHROW;
 
@@ -293,6 +302,8 @@ extern void starpu_omp_barrier(void) __STARPU_OMP_NOTHROW;
 
    This function can be used to implement <c>\#pragma omp
    critical</c>.
+
+   See \ref OMPCritical for more details.
 */
 extern void starpu_omp_critical(void (*f)(void *arg), void *arg, const char *name) __STARPU_OMP_NOTHROW;
 
@@ -304,6 +315,8 @@ extern void starpu_omp_critical(void (*f)(void *arg), void *arg, const char *nam
 
    This function together with #starpu_omp_critical_inline_end can be used to
    implement <c>\#pragma omp critical</c> without code outlining.
+
+   See \ref OMPCritical for more details.
 */
 extern void starpu_omp_critical_inline_begin(const char *name) __STARPU_OMP_NOTHROW;
 
@@ -315,6 +328,8 @@ extern void starpu_omp_critical_inline_begin(const char *name) __STARPU_OMP_NOTH
 
    This function together with #starpu_omp_critical_inline_begin can be used to
    implement <c>\#pragma omp critical</c> without code outlining.
+
+   See \ref OMPCritical for more details.
 */
 extern void starpu_omp_critical_inline_end(const char *name) __STARPU_OMP_NOTHROW;
 
@@ -334,6 +349,7 @@ extern void starpu_omp_critical_inline_end(const char *name) __STARPU_OMP_NOTHRO
    (<c>nowait==0</c>) or not (<c>nowait==!0</c>).
 
    This function can be used to implement <c>\#pragma omp single</c>.
+   See \ref OMPSingle for more details.
 */
 extern void starpu_omp_single(void (*f)(void *arg), void *arg, int nowait) __STARPU_OMP_NOTHROW;
 
@@ -346,6 +362,7 @@ extern void starpu_omp_single(void (*f)(void *arg), void *arg, int nowait) __STA
    outlining.
    \return <c>!0</c> if the calling thread has won the election.
    \return <c>0</c> if the calling thread has lost the election.
+   See \ref OMPSingle for more details.
 */
 extern int starpu_omp_single_inline(void) __STARPU_OMP_NOTHROW;
 
@@ -360,6 +377,8 @@ extern int starpu_omp_single_inline(void) __STARPU_OMP_NOTHROW;
    \sa starpu_omp_single_copyprivate_inline
    \sa starpu_omp_single_copyprivate_inline_begin
    \sa starpu_omp_single_copyprivate_inline_end
+
+   See \ref OMPSingle for more details.
 */
 extern void starpu_omp_single_copyprivate(void (*f)(void *arg, void *data, unsigned long long data_size), void *arg, void *data, unsigned long long data_size) __STARPU_OMP_NOTHROW;
 
@@ -372,6 +391,8 @@ extern void starpu_omp_single_copyprivate(void (*f)(void *arg, void *data, unsig
 
    \sa starpu_omp_single_copyprivate_inline
    \sa starpu_omp_single_copyprivate_inline_end
+
+   See \ref OMPSingle for more details.
 */
 extern void *starpu_omp_single_copyprivate_inline_begin(void *data) __STARPU_OMP_NOTHROW;
 
@@ -381,11 +402,13 @@ extern void *starpu_omp_single_copyprivate_inline_begin(void *data) __STARPU_OMP
    the task that won the election. This function can be used to implement
    <c>\#pragma omp single</c> with a copyprivate clause without code outlining.
 
-   \return the copyprivate pointer for tasks that lost the election and therefore did not execute the code of the single section.
-   \return <c>NULL</c> for the task that won the election and executed the code of the single section.
+   Return the copyprivate pointer for tasks that lost the election and therefore did not execute the code of the single section.
+   Return <c>NULL</c> for the task that won the election and executed the code of the single section.
 
    \sa starpu_omp_single_copyprivate_inline
    \sa starpu_omp_single_copyprivate_inline_begin
+
+   See \ref OMPSingle for more details.
 */
 extern void starpu_omp_single_copyprivate_inline_end(void) __STARPU_OMP_NOTHROW;
 
@@ -408,6 +431,7 @@ extern void starpu_omp_single_copyprivate_inline_end(void) __STARPU_OMP_NOTHROW;
    returning, \p arg, the free \p arg argument.
 
    This function can be used to implement <c>\#pragma omp for</c>.
+   See \ref OMPFor for more details.
 */
 extern void starpu_omp_for(void (*f)(unsigned long long _first_i, unsigned long long _nb_i, void *arg), void *arg, unsigned long long nb_iterations, unsigned long long chunk, int schedule, int ordered, int nowait) __STARPU_OMP_NOTHROW;
 
@@ -428,6 +452,8 @@ extern void starpu_omp_for(void (*f)(unsigned long long _first_i, unsigned long
    the parallel region.
 
    \sa starpu_omp_for
+
+   See \ref OMPFor for more details.
 */
 extern int starpu_omp_for_inline_first(unsigned long long nb_iterations, unsigned long long chunk, int schedule, int ordered, unsigned long long *_first_i, unsigned long long *_nb_i) __STARPU_OMP_NOTHROW;
 
@@ -448,6 +474,8 @@ extern int starpu_omp_for_inline_first(unsigned long long nb_iterations, unsigne
    threads of the parallel region.
 
    \sa starpu_omp_for
+
+   See \ref OMPFor for more details.
 */
 extern int starpu_omp_for_inline_next(unsigned long long nb_iterations, unsigned long long chunk, int schedule, int ordered, unsigned long long *_first_i, unsigned long long *_nb_i) __STARPU_OMP_NOTHROW;
 
@@ -462,6 +490,8 @@ extern int starpu_omp_for_inline_next(unsigned long long nb_iterations, unsigned
    This function can be used to implement <c>\#pragma omp for</c>.
 
    \sa starpu_omp_for
+
+   See \ref OMPFor for more details.
 */
 extern void starpu_omp_for_alt(void (*f)(unsigned long long _begin_i, unsigned long long _end_i, void *arg), void *arg, unsigned long long nb_iterations, unsigned long long chunk, int schedule, int ordered, int nowait) __STARPU_OMP_NOTHROW;
 
@@ -474,6 +504,8 @@ extern void starpu_omp_for_alt(void (*f)(unsigned long long _begin_i, unsigned l
    \sa starpu_omp_for
    \sa starpu_omp_for_alt
    \sa starpu_omp_for_inline_first
+
+   See \ref OMPFor for more details.
 */
 extern int starpu_omp_for_inline_first_alt(unsigned long long nb_iterations, unsigned long long chunk, int schedule, int ordered, unsigned long long *_begin_i, unsigned long long *_end_i) __STARPU_OMP_NOTHROW;
 
@@ -486,6 +518,8 @@ extern int starpu_omp_for_inline_first_alt(unsigned long long nb_iterations, uns
    \sa starpu_omp_for
    \sa starpu_omp_for_alt
    \sa starpu_omp_for_inline_next
+
+   See \ref OMPFor for more details.
 */
 extern int starpu_omp_for_inline_next_alt(unsigned long long nb_iterations, unsigned long long chunk, int schedule, int ordered, unsigned long long *_begin_i, unsigned long long *_end_i) __STARPU_OMP_NOTHROW;
 
@@ -496,6 +530,8 @@ extern int starpu_omp_for_inline_next_alt(unsigned long long nb_iterations, unsi
    an argument passed to function \p f.
 
    This function can be used to implement <c>\#pragma omp ordered</c>.
+
+   See \ref OMPFor for more details.
 */
 extern void starpu_omp_ordered(void (*f)(void *arg), void *arg) __STARPU_OMP_NOTHROW;
 
@@ -505,6 +541,8 @@ extern void starpu_omp_ordered(void (*f)(void *arg), void *arg) __STARPU_OMP_NOT
 
    This function together with #starpu_omp_ordered_inline_end can be used to
    implement <c>\#pragma omp ordered</c> without code code outlining.
+
+   See \ref OMPFor for more details.
 */
 extern void starpu_omp_ordered_inline_begin(void) __STARPU_OMP_NOTHROW;
 
@@ -513,6 +551,8 @@ extern void starpu_omp_ordered_inline_begin(void) __STARPU_OMP_NOTHROW;
 
    This function together with #starpu_omp_ordered_inline_begin can be used to
    implement <c>\#pragma omp ordered</c> without code code outlining.
+
+   See \ref OMPFor for more details.
 */
 extern void starpu_omp_ordered_inline_end(void) __STARPU_OMP_NOTHROW;
 
@@ -525,6 +565,8 @@ extern void starpu_omp_ordered_inline_end(void) __STARPU_OMP_NOTHROW;
    the execution of all the sections (<c>nowait==0</c>) or not (<c>nowait==!0</c>).
 
    This function can be used to implement <c>\#pragma omp sections</c> and <c>\#pragma omp section</c>.
+
+   See \ref OMPSections for more details.
  */
 extern void starpu_omp_sections(unsigned long long nb_sections, void (**section_f)(void *arg), void **section_arg, int nowait) __STARPU_OMP_NOTHROW;
 
@@ -541,6 +583,8 @@ extern void starpu_omp_sections(unsigned long long nb_sections, void (**section_
    This function can be used to implement <c>\#pragma omp sections</c> and <c>\#pragma omp section</c>.
 
    \sa starpu_omp_sections
+
+   See \ref OMPSections for more details.
  */
 extern void starpu_omp_sections_combined(unsigned long long nb_sections, void (*section_f)(unsigned long long section_num, void *arg), void *section_arg, int nowait) __STARPU_OMP_NOTHROW;
 
@@ -558,6 +602,8 @@ extern void starpu_omp_sections_combined(unsigned long long nb_sections, void (*
    \p attr specifies the attributes for the generated task region.
 
    This function can be used to implement <c>\#pragma omp task</c>.
+
+   See \ref OMPTaskExplicit for more details.
  */
 extern void starpu_omp_task_region(const struct starpu_omp_task_region_attr *attr) __STARPU_OMP_NOTHROW;
 
@@ -567,6 +613,8 @@ extern void starpu_omp_task_region(const struct starpu_omp_task_region_attr *att
    task.
 
    This function can be used to implement <c>\#pragma omp taskwait</c>.
+
+   See \ref OMPTaskSyncs for more details.
  */
 extern void starpu_omp_taskwait(void) __STARPU_OMP_NOTHROW;
 
@@ -578,6 +626,8 @@ extern void starpu_omp_taskwait(void) __STARPU_OMP_NOTHROW;
 
    \sa starpu_omp_taskgroup_inline_begin
    \sa starpu_omp_taskgroup_inline_end
+
+   See \ref OMPTaskSyncs for more details.
  */
 extern void starpu_omp_taskgroup(void (*f)(void *arg), void *arg) __STARPU_OMP_NOTHROW;
 
@@ -589,6 +639,8 @@ extern void starpu_omp_taskgroup(void (*f)(void *arg), void *arg) __STARPU_OMP_N
 
    \sa starpu_omp_taskgroup
    \sa starpu_omp_taskgroup_inline_end
+
+   See \ref OMPTaskSyncs for more details.
  */
 extern void starpu_omp_taskgroup_inline_begin(void) __STARPU_OMP_NOTHROW;
 
@@ -600,6 +652,8 @@ extern void starpu_omp_taskgroup_inline_begin(void) __STARPU_OMP_NOTHROW;
 
    \sa starpu_omp_taskgroup
    \sa starpu_omp_taskgroup_inline_begin
+
+   See \ref OMPTaskSyncs for more details.
  */
 extern void starpu_omp_taskgroup_inline_end(void) __STARPU_OMP_NOTHROW;
 
@@ -626,6 +680,8 @@ extern void starpu_omp_taskloop_inline_end(const struct starpu_omp_task_region_a
    \sa starpu_omp_get_thread_num
    \sa starpu_omp_get_max_threads
    \sa starpu_omp_get_num_procs
+
+   See \ref OMPStandard for more details.
 */
 extern void starpu_omp_set_num_threads(int threads) __STARPU_OMP_NOTHROW;
 
@@ -638,8 +694,10 @@ extern void starpu_omp_set_num_threads(int threads) __STARPU_OMP_NOTHROW;
    \sa starpu_omp_get_thread_num
    \sa starpu_omp_get_max_threads
    \sa starpu_omp_get_num_procs
+
+   See \ref OMPStandard for more details.
  */
-extern int starpu_omp_get_num_threads() __STARPU_OMP_NOTHROW;
+extern int starpu_omp_get_num_threads(void) __STARPU_OMP_NOTHROW;
 
 /**
    Return the rank of the current thread among the threads
@@ -651,8 +709,10 @@ extern int starpu_omp_get_num_threads() __STARPU_OMP_NOTHROW;
    \sa starpu_omp_get_num_threads
    \sa starpu_omp_get_max_threads
    \sa starpu_omp_get_num_procs
+
+   See \ref OMPStandard for more details.
  */
-extern int starpu_omp_get_thread_num() __STARPU_OMP_NOTHROW;
+extern int starpu_omp_get_thread_num(void) __STARPU_OMP_NOTHROW;
 
 /**
    Return the maximum number of threads that can be used to
@@ -664,8 +724,10 @@ extern int starpu_omp_get_thread_num() __STARPU_OMP_NOTHROW;
    \sa starpu_omp_get_num_threads
    \sa starpu_omp_get_thread_num
    \sa starpu_omp_get_num_procs
+
+   See \ref OMPStandard for more details.
  */
-extern int starpu_omp_get_max_threads() __STARPU_OMP_NOTHROW;
+extern int starpu_omp_get_max_threads(void) __STARPU_OMP_NOTHROW;
 
 /**
    Return the number of StarPU CPU workers.
@@ -676,6 +738,8 @@ extern int starpu_omp_get_max_threads() __STARPU_OMP_NOTHROW;
    \sa starpu_omp_get_num_threads
    \sa starpu_omp_get_thread_num
    \sa starpu_omp_get_max_threads
+
+   See \ref OMPStandard for more details.
 */
 extern int starpu_omp_get_num_procs(void) __STARPU_OMP_NOTHROW;
 
@@ -684,6 +748,8 @@ extern int starpu_omp_get_num_procs(void) __STARPU_OMP_NOTHROW;
 
    \return <c>!0</c> if called from a parallel region scope.
    \return <c>0</c> otherwise.
+
+   See \ref OMPStandard for more details.
 */
 extern int starpu_omp_in_parallel(void) __STARPU_OMP_NOTHROW;
 
@@ -693,6 +759,8 @@ extern int starpu_omp_in_parallel(void) __STARPU_OMP_NOTHROW;
    Note: The StarPU OpenMP runtime support currently ignores the argument of this function.
 
    \sa starpu_omp_get_dynamic
+
+   See \ref OMPStandard for more details.
 */
 extern void starpu_omp_set_dynamic(int dynamic_threads) __STARPU_OMP_NOTHROW;
 
@@ -703,6 +771,8 @@ extern void starpu_omp_set_dynamic(int dynamic_threads) __STARPU_OMP_NOTHROW;
    \return <c>0</c> otherwise.
 
    \sa starpu_omp_set_dynamic
+
+   See \ref OMPStandard for more details.
 */
 extern int starpu_omp_get_dynamic(void) __STARPU_OMP_NOTHROW;
 
@@ -716,6 +786,8 @@ extern int starpu_omp_get_dynamic(void) __STARPU_OMP_NOTHROW;
    \sa starpu_omp_set_max_active_levels
    \sa starpu_omp_get_level
    \sa starpu_omp_get_active_level
+
+   See \ref OMPStandard for more details.
 */
 extern void starpu_omp_set_nested(int nested) __STARPU_OMP_NOTHROW;
 
@@ -730,30 +802,36 @@ extern void starpu_omp_set_nested(int nested) __STARPU_OMP_NOTHROW;
    \sa starpu_omp_set_max_active_levels
    \sa starpu_omp_get_level
    \sa starpu_omp_get_active_level
+
+   See \ref OMPStandard for more details.
 */
 extern int starpu_omp_get_nested(void) __STARPU_OMP_NOTHROW;
 
 /**
    Return the state of the cancel ICVS var.
+
+   See \ref OMPStandard for more details.
  */
 extern int starpu_omp_get_cancellation(void) __STARPU_OMP_NOTHROW;
 
 /**
    Set the default scheduling kind for upcoming loops within the
    current parallel section. \p kind is the scheduler kind, \p modifier
-   complements the scheduler kind with informations such as the chunk size,
+   complements the scheduler kind with information such as the chunk size,
    in accordance with the OpenMP specification.
 
    \sa starpu_omp_get_schedule
+
+   See \ref OMPFor for more details.
  */
 extern void starpu_omp_set_schedule(enum starpu_omp_sched_value kind, int modifier) __STARPU_OMP_NOTHROW;
 
 /**
-   Return the current selected default loop scheduler.
-
-   \return the kind and the modifier of the current default loop scheduler.
+   Return the kind and the modifier of the current default loop scheduler.
 
    \sa starpu_omp_set_schedule
+
+   See \ref OMPStandard for more details.
 */
 extern void starpu_omp_get_schedule(enum starpu_omp_sched_value *kind, int *modifier) __STARPU_OMP_NOTHROW;
 
@@ -761,6 +839,8 @@ extern void starpu_omp_get_schedule(enum starpu_omp_sched_value *kind, int *modi
    Return the number of StarPU CPU workers.
 
    \return the number of StarPU CPU workers.
+
+   See \ref OMPStandard for more details.
 */
 extern int starpu_omp_get_thread_limit(void) __STARPU_OMP_NOTHROW;
 
@@ -774,6 +854,8 @@ extern int starpu_omp_get_thread_limit(void) __STARPU_OMP_NOTHROW;
    \sa starpu_omp_get_max_active_levels
    \sa starpu_omp_get_level
    \sa starpu_omp_get_active_level
+
+   See \ref OMPStandard for more details.
 */
 extern void starpu_omp_set_max_active_levels(int max_levels) __STARPU_OMP_NOTHROW;
 
@@ -787,6 +869,8 @@ extern void starpu_omp_set_max_active_levels(int max_levels) __STARPU_OMP_NOTHRO
    \sa starpu_omp_set_max_active_levels
    \sa starpu_omp_get_level
    \sa starpu_omp_get_active_level
+
+   See \ref OMPStandard for more details.
 */
 extern int starpu_omp_get_max_active_levels(void) __STARPU_OMP_NOTHROW;
 
@@ -800,6 +884,8 @@ extern int starpu_omp_get_max_active_levels(void) __STARPU_OMP_NOTHROW;
    \sa starpu_omp_get_max_active_levels
    \sa starpu_omp_set_max_active_levels
    \sa starpu_omp_get_active_level
+
+   See \ref OMPStandard for more details.
 */
 extern int starpu_omp_get_level(void) __STARPU_OMP_NOTHROW;
 
@@ -807,6 +893,8 @@ extern int starpu_omp_get_level(void) __STARPU_OMP_NOTHROW;
    Return the number of the ancestor of the current parallel section.
 
    \return the number of the ancestor of the current parallel section.
+
+   See \ref OMPStandard for more details.
 */
 extern int starpu_omp_get_ancestor_thread_num(int level) __STARPU_OMP_NOTHROW;
 
@@ -814,6 +902,8 @@ extern int starpu_omp_get_ancestor_thread_num(int level) __STARPU_OMP_NOTHROW;
    Return the size of the team of the current parallel section.
 
    \return the size of the team of the current parallel section.
+
+   See \ref OMPStandard for more details.
 */
 extern int starpu_omp_get_team_size(int level) __STARPU_OMP_NOTHROW;
 
@@ -827,6 +917,8 @@ extern int starpu_omp_get_team_size(int level) __STARPU_OMP_NOTHROW;
    \sa starpu_omp_get_max_active_levels
    \sa starpu_omp_set_max_active_levels
    \sa starpu_omp_get_level
+
+   See \ref OMPStandard for more details.
 */
 extern int starpu_omp_get_active_level(void) __STARPU_OMP_NOTHROW;
 
@@ -835,6 +927,8 @@ extern int starpu_omp_get_active_level(void) __STARPU_OMP_NOTHROW;
 
    \return <c>!0</c> if called from a final task.
    \return <c>0</c> otherwise.
+
+   See \ref OMPStandard for more details.
 */
 extern int starpu_omp_in_final(void) __STARPU_OMP_NOTHROW;
 
@@ -842,19 +936,59 @@ extern int starpu_omp_in_final(void) __STARPU_OMP_NOTHROW;
    Return the proc_bind setting of the current parallel region.
 
    \return the proc_bind setting of the current parallel region.
+
+   See \ref OMPStandard for more details.
 */
 extern enum starpu_omp_proc_bind_value starpu_omp_get_proc_bind(void) __STARPU_OMP_NOTHROW;
 
+/**
+   Return the number of places available to the execution environment in the place list.
+
+   \return the number of places available to the execution environment in the place list.
+
+   See \ref OMPStandard for more details.
+*/
 extern int starpu_omp_get_num_places(void) __STARPU_OMP_NOTHROW;
 
+/**
+   Return the number of processors available to the execution environment in the specified place.
+
+   \return the number of processors available to the execution environment in the specified place.
+
+   See \ref OMPStandard for more details.
+*/
 extern int starpu_omp_get_place_num_procs(int place_num) __STARPU_OMP_NOTHROW;
 
+/**
+   Return the numerical identifiers of the processors available to the execution environment in the specified place.
+
+   See \ref OMPStandard for more details.
+*/
 extern void starpu_omp_get_place_proc_ids(int place_num, int *ids) __STARPU_OMP_NOTHROW;
 
+/**
+   Return the place number of the place to which the encountering thread is bound.
+
+   \return the place number of the place to which the encountering thread is bound.
+
+   See \ref OMPStandard for more details.
+*/
 extern int starpu_omp_get_place_num(void) __STARPU_OMP_NOTHROW;
 
+/**
+   Return the number of places in the place partition of the innermost implicit task.
+
+   \return the number of places in the place partition of the innermost implicit task.
+
+   See \ref OMPStandard for more details.
+*/
 extern int starpu_omp_get_partition_num_places(void) __STARPU_OMP_NOTHROW;
 
+/**
+   Return the list of place numbers corresponding to the places in the place-partition-var ICV of the innermost implicit task.
+
+   See \ref OMPStandard for more details.
+*/
 extern void starpu_omp_get_partition_place_nums(int *place_nums) __STARPU_OMP_NOTHROW;
 
 /**
@@ -864,6 +998,8 @@ extern void starpu_omp_get_partition_place_nums(int *place_nums) __STARPU_OMP_NO
 
    \sa starpu_omp_get_default_device
    \sa starpu_omp_is_initial_device
+
+   See \ref OMPStandard for more details.
 */
 extern void starpu_omp_set_default_device(int device_num) __STARPU_OMP_NOTHROW;
 
@@ -874,6 +1010,8 @@ extern void starpu_omp_set_default_device(int device_num) __STARPU_OMP_NOTHROW;
 
    \sa starpu_omp_set_default_device
    \sa starpu_omp_is_initial_device
+
+   See \ref OMPStandard for more details.
  */
 extern int starpu_omp_get_default_device(void) __STARPU_OMP_NOTHROW;
 
@@ -881,6 +1019,8 @@ extern int starpu_omp_get_default_device(void) __STARPU_OMP_NOTHROW;
    Return the number of the devices.
 
    \return the number of the devices.
+
+   See \ref OMPStandard for more details.
 */
 extern int starpu_omp_get_num_devices(void) __STARPU_OMP_NOTHROW;
 
@@ -890,6 +1030,8 @@ extern int starpu_omp_get_num_devices(void) __STARPU_OMP_NOTHROW;
    \return the number of teams in the current teams region.
 
    \sa starpu_omp_get_num_teams
+
+   See \ref OMPStandard for more details.
 */
 extern int starpu_omp_get_num_teams(void) __STARPU_OMP_NOTHROW;
 
@@ -899,16 +1041,25 @@ extern int starpu_omp_get_num_teams(void) __STARPU_OMP_NOTHROW;
    \return the team number of the calling thread.
 
    \sa starpu_omp_get_num_teams
+
+   See \ref OMPStandard for more details.
 */
 extern int starpu_omp_get_team_num(void) __STARPU_OMP_NOTHROW;
 
 /**
    Check whether the current device is the initial device or not.
+
+   See \ref OMPStandard for more details.
 */
 extern int starpu_omp_is_initial_device(void) __STARPU_OMP_NOTHROW;
 
 /**
- */
+   Return a device number that represents the host device.
+
+   \return a device number that represents the host device.
+
+   See \ref OMPStandard for more details.
+*/
 extern int starpu_omp_get_initial_device(void) __STARPU_OMP_NOTHROW;
 
 /**
@@ -920,6 +1071,8 @@ extern int starpu_omp_get_initial_device(void) __STARPU_OMP_NOTHROW;
 
    \sa starpu_omp_set_default_device
    \sa starpu_omp_get_default_device
+
+   See \ref OMPStandard for more details.
 */
 extern int starpu_omp_get_max_task_priority(void) __STARPU_OMP_NOTHROW;
 
@@ -930,6 +1083,8 @@ extern int starpu_omp_get_max_task_priority(void) __STARPU_OMP_NOTHROW;
    \sa starpu_omp_set_lock
    \sa starpu_omp_unset_lock
    \sa starpu_omp_test_lock
+
+   See \ref OMPSimpleLock for more details.
 */
 extern void starpu_omp_init_lock(starpu_omp_lock_t *lock) __STARPU_OMP_NOTHROW;
 
@@ -940,6 +1095,8 @@ extern void starpu_omp_init_lock(starpu_omp_lock_t *lock) __STARPU_OMP_NOTHROW;
    \sa starpu_omp_set_lock
    \sa starpu_omp_unset_lock
    \sa starpu_omp_test_lock
+
+   See \ref OMPSimpleLock for more details.
 */
 extern void starpu_omp_destroy_lock(starpu_omp_lock_t *lock) __STARPU_OMP_NOTHROW;
 
@@ -951,6 +1108,8 @@ extern void starpu_omp_destroy_lock(starpu_omp_lock_t *lock) __STARPU_OMP_NOTHRO
    \sa starpu_omp_destroy_lock
    \sa starpu_omp_unset_lock
    \sa starpu_omp_test_lock
+
+   See \ref OMPSimpleLock for more details.
 */
 extern void starpu_omp_set_lock(starpu_omp_lock_t *lock) __STARPU_OMP_NOTHROW;
 
@@ -962,6 +1121,8 @@ extern void starpu_omp_set_lock(starpu_omp_lock_t *lock) __STARPU_OMP_NOTHROW;
    \sa starpu_omp_destroy_lock
    \sa starpu_omp_set_lock
    \sa starpu_omp_test_lock
+
+   See \ref OMPSimpleLock for more details.
 */
 extern void starpu_omp_unset_lock(starpu_omp_lock_t *lock) __STARPU_OMP_NOTHROW;
 
@@ -976,6 +1137,8 @@ extern void starpu_omp_unset_lock(starpu_omp_lock_t *lock) __STARPU_OMP_NOTHROW;
    \sa starpu_omp_destroy_lock
    \sa starpu_omp_set_lock
    \sa starpu_omp_unset_lock
+
+   See \ref OMPSimpleLock for more details.
 */
 extern int starpu_omp_test_lock(starpu_omp_lock_t *lock) __STARPU_OMP_NOTHROW;
 
@@ -986,6 +1149,8 @@ extern int starpu_omp_test_lock(starpu_omp_lock_t *lock) __STARPU_OMP_NOTHROW;
    \sa starpu_omp_set_nest_lock
    \sa starpu_omp_unset_nest_lock
    \sa starpu_omp_test_nest_lock
+
+   See \ref OMPNestableLock for more details.
 */
 extern void starpu_omp_init_nest_lock(starpu_omp_nest_lock_t *lock) __STARPU_OMP_NOTHROW;
 
@@ -996,6 +1161,8 @@ extern void starpu_omp_init_nest_lock(starpu_omp_nest_lock_t *lock) __STARPU_OMP
    \sa starpu_omp_set_nest_lock
    \sa starpu_omp_unset_nest_lock
    \sa starpu_omp_test_nest_lock
+
+   See \ref OMPNestableLock for more details.
 */
 extern void starpu_omp_destroy_nest_lock(starpu_omp_nest_lock_t *lock) __STARPU_OMP_NOTHROW;
 
@@ -1010,6 +1177,8 @@ extern void starpu_omp_destroy_nest_lock(starpu_omp_nest_lock_t *lock) __STARPU_
    \sa starpu_omp_destroy_nest_lock
    \sa starpu_omp_unset_nest_lock
    \sa starpu_omp_test_nest_lock
+
+   See \ref OMPNestableLock for more details.
 */
 extern void starpu_omp_set_nest_lock(starpu_omp_nest_lock_t *lock) __STARPU_OMP_NOTHROW;
 
@@ -1026,6 +1195,8 @@ extern void starpu_omp_set_nest_lock(starpu_omp_nest_lock_t *lock) __STARPU_OMP_
    \sa starpu_omp_destroy_nest_lock
    \sa starpu_omp_set_nest_lock
    \sa starpu_omp_test_nest_lock
+
+   See \ref OMPNestableLock for more details.
 */
 extern void starpu_omp_unset_nest_lock(starpu_omp_nest_lock_t *lock) __STARPU_OMP_NOTHROW;
 
@@ -1043,6 +1214,8 @@ extern void starpu_omp_unset_nest_lock(starpu_omp_nest_lock_t *lock) __STARPU_OM
    \sa starpu_omp_destroy_nest_lock
    \sa starpu_omp_set_nest_lock
    \sa starpu_omp_unset_nest_lock
+
+   See \ref OMPNestableLock for more details.
 */
 extern int starpu_omp_test_nest_lock(starpu_omp_nest_lock_t *lock) __STARPU_OMP_NOTHROW;
 
@@ -1069,6 +1242,8 @@ extern void starpu_omp_atomic_fallback_inline_end(void) __STARPU_OMP_NOTHROW;
    \return the elapsed wallclock time in seconds.
 
    \sa starpu_omp_get_wtick
+
+   See \ref OMPStandard for more details.
 */
 extern double starpu_omp_get_wtime(void) __STARPU_OMP_NOTHROW;
 
@@ -1078,6 +1253,8 @@ extern double starpu_omp_get_wtime(void) __STARPU_OMP_NOTHROW;
    \return the precision of the time used by \p starpu_omp_get_wtime().
 
    \sa starpu_omp_get_wtime
+
+   See \ref OMPStandard for more details.
 */
 extern double starpu_omp_get_wtick(void) __STARPU_OMP_NOTHROW;
 
@@ -1092,9 +1269,39 @@ extern double starpu_omp_get_wtick(void) __STARPU_OMP_NOTHROW;
 extern void starpu_omp_vector_annotate(starpu_data_handle_t handle, uint32_t slice_base) __STARPU_OMP_NOTHROW;
 
 /**
+   Only use internally by StarPU.
  */
 extern struct starpu_arbiter *starpu_omp_get_default_arbiter(void) __STARPU_OMP_NOTHROW;
 
+/**
+   Register a handle for ptr->handle data lookup.
+
+   \sa starpu_omp_handle_unregister
+   \sa starpu_omp_data_lookup
+
+   See \ref OMPDataDependencies for more details.
+ */
+extern void starpu_omp_handle_register(starpu_data_handle_t handle) __STARPU_OMP_NOTHROW;
+
+/**
+   Unregister a handle from ptr->handle data lookup.
+
+   \sa starpu_omp_handle_register
+   \sa starpu_omp_data_lookup
+
+   See \ref OMPDataDependencies for more details.
+ */
+extern void starpu_omp_handle_unregister(starpu_data_handle_t handle) __STARPU_OMP_NOTHROW;
+
+/**
+   Return the handle corresponding to the data pointed to by the \p ptr host pointer.
+
+   \return the handle or \c NULL if not found.
+
+   See \ref OMPDataDependencies for more details.
+*/
+extern starpu_data_handle_t starpu_omp_data_lookup(const void *ptr) __STARPU_OMP_NOTHROW;
+
 /** @} */
 
 #ifdef __cplusplus
