@@ -1,6 +1,6 @@
 /* StarPU --- Runtime system for heterogeneous multicore architectures.
  *
- * Copyright (C) 2012-2021  Université de Bordeaux, CNRS (LaBRI UMR 5800), Inria
+ * Copyright (C) 2009-2025  University of Bordeaux, CNRS (LaBRI UMR 5800), Inria
  *
  * StarPU is free software; you can redistribute it and/or modify
  * it under the terms of the GNU Lesser General Public License as published by
@@ -17,6 +17,10 @@
 #ifndef __STARPU_SINK_H__
 #define __STARPU_SINK_H__
 
+#ifdef __cplusplus
+extern "C" {
+#endif
+
 /**
    @defgroup API_Sink Sink
    @{
@@ -26,4 +30,8 @@ void starpu_sink_common_worker(int argc, char **argv);
 
 /** @} */
 
+#ifdef __cplusplus
+}
+#endif
+
 #endif /* __STARPU_SINK_H__ */
