@@ -1,8 +1,8 @@
 /* StarPU --- Runtime system for heterogeneous multicore architectures.
  *
- * Copyright (C) 2009-2023  Université de Bordeaux, CNRS (LaBRI UMR 5800), Inria
- * Copyright (C) 2011       Télécom-SudParis
- * Copyright (C) 2016       Uppsala University
+ * Copyright (C) 2009-2025  University of Bordeaux, CNRS (LaBRI UMR 5800), Inria
+ * Copyright (C) 2016-2016  Uppsala University
+ * Copyright (C) 2011-2011  Télécom Sud Paris
  *
  * StarPU is free software; you can redistribute it and/or modify
  * it under the terms of the GNU Lesser General Public License as published by
@@ -16,11 +16,11 @@
  * See the GNU Lesser General Public License in COPYING.LGPL for more details.
  */
 
+#include <starpu.h>
+
 #ifndef __STARPU_TASK_DEP_H__
 #define __STARPU_TASK_DEP_H__
 
-#include <starpu.h>
-
 #ifdef __cplusplus
 extern "C" {
 #endif
@@ -240,6 +240,14 @@ void starpu_tag_notify_restart_from_apps(starpu_tag_t id);
  */
 struct starpu_task *starpu_tag_get_task(starpu_tag_t id);
 
+/**
+   Calls starpu_tag_remove() for all tags.
+   The current implementation requires that no starpu_tag_wait_array() is
+   currently pending.
+   See \ref TasksAndTagsDependencies for more details.
+ */
+void starpu_tag_clear(void);
+
 /** @} */
 
 #ifdef __cplusplus
