@@ -1,6 +1,6 @@
 /* StarPU --- Runtime system for heterogeneous multicore architectures.
  *
- * Copyright (C) 2015-2021  Université de Bordeaux, CNRS (LaBRI UMR 5800), Inria
+ * Copyright (C) 2015-2025  University of Bordeaux, CNRS (LaBRI UMR 5800), Inria
  *
  * StarPU is free software; you can redistribute it and/or modify
  * it under the terms of the GNU Lesser General Public License as published by
@@ -22,13 +22,15 @@
 #include <starpu_mpi.h>
 #include "../helper.h"
 
+MPI_Comm newcomm;
+
 void func_cpu(void *descr[], void *_args)
 {
 	int *value = (int *)STARPU_VARIABLE_GET_PTR(descr[0]);
 	int rank;
 
 	starpu_codelet_unpack_args(_args, &rank);
-	FPRINTF_MPI(stderr, "Executing codelet with value %d and rank %d\n", *value, rank);
+	FPRINTF_MPI_COMM(stderr, newcomm, "Executing codelet with value %d and rank %d\n", *value, rank);
 	STARPU_ASSERT_MSG(*value == rank, "Received value %d is not the expected value %d\n", *value, rank);
 }
 
@@ -44,7 +46,6 @@ int main(int argc, char **argv)
 {
 	int size, x;
 	int color;
-	MPI_Comm newcomm;
 	int rank, newrank;
 	int ret;
 	starpu_data_handle_t data[3];
@@ -60,15 +61,15 @@ int main(int argc, char **argv)
 	if (thread_support < MPI_THREAD_FUNNELED)
 		fprintf(stderr,"Warning: MPI does not have thread support!\n");
 
-        MPI_Comm_rank(MPI_COMM_WORLD, &rank);
-        MPI_Comm_size(MPI_COMM_WORLD, &size);
+	MPI_Comm_rank(MPI_COMM_WORLD, &rank);
+	MPI_Comm_size(MPI_COMM_WORLD, &size);
 
-        if (size < 4)
-        {
+	if (size < 4)
+	{
 		FPRINTF(stderr, "We need at least 4 processes.\n");
-                MPI_Finalize();
-                return STARPU_TEST_SKIPPED;
-        }
+		MPI_Finalize();
+		return STARPU_TEST_SKIPPED;
+	}
 
 	color = rank%2;
 	MPI_Comm_split(MPI_COMM_WORLD, color, rank, &newcomm);
@@ -86,8 +87,11 @@ int main(int argc, char **argv)
 		FPRINTF(stderr, "[%d][%d] received %d\n", rank, newrank, x);
 	}
 
-        ret = starpu_mpi_init_conf(NULL, NULL, 0, MPI_COMM_WORLD, NULL);
-        STARPU_CHECK_RETURN_VALUE(ret, "starpu_mpi_init_conf");
+	ret = starpu_mpi_init_conf(NULL, NULL, 0, MPI_COMM_WORLD, NULL);
+	STARPU_CHECK_RETURN_VALUE(ret, "starpu_mpi_init_conf");
+
+	ret = starpu_mpi_comm_register(newcomm);
+	STARPU_CHECK_RETURN_VALUE(ret, "starpu_mpi_comm_register");
 
 	if (rank == 0)
 	{
@@ -110,16 +114,21 @@ int main(int argc, char **argv)
 	if (newrank == 0)
 	{
 		starpu_mpi_req req[2];
-		starpu_mpi_issend(data[1], &req[0], 1, 22, newcomm);
-		starpu_mpi_isend(data[0], &req[1], 1, 12, newcomm);
-		starpu_mpi_wait(&req[0], MPI_STATUS_IGNORE);
-		starpu_mpi_wait(&req[1], MPI_STATUS_IGNORE);
+		ret = starpu_mpi_issend(data[1], &req[0], 1, 22, newcomm);
+		STARPU_CHECK_RETURN_VALUE(ret, "starpu_mpi_issend");
+		ret = starpu_mpi_isend(data[0], &req[1], 1, 12, newcomm);
+		STARPU_CHECK_RETURN_VALUE(ret, "starpu_mpi_isend");
+		ret = starpu_mpi_wait(&req[0], MPI_STATUS_IGNORE);
+		STARPU_CHECK_RETURN_VALUE(ret, "starpu_mpi_wait");
+		ret = starpu_mpi_wait(&req[1], MPI_STATUS_IGNORE);
+		STARPU_CHECK_RETURN_VALUE(ret, "starpu_mpi_wait");
 	}
 	else if (newrank == 1)
 	{
 		int *xx;
 
-		starpu_mpi_recv(data[0], 0, 12, newcomm, MPI_STATUS_IGNORE);
+		ret = starpu_mpi_recv(data[0], 0, 12, newcomm, MPI_STATUS_IGNORE);
+		STARPU_CHECK_RETURN_VALUE(ret, "starpu_mpi_recv");
 		starpu_data_acquire(data[0], STARPU_R);
 		xx = (int *)starpu_variable_get_local_ptr(data[0]);
 		FPRINTF(stderr, "[%d][%d] received %d\n", rank, newrank, *xx);
@@ -128,7 +137,8 @@ int main(int argc, char **argv)
 
 		starpu_variable_data_register(&data[1], -1, (uintptr_t)NULL, sizeof(int));
 		starpu_mpi_data_register_comm(data[1], 22, 0, newcomm);
-		starpu_mpi_recv(data[0], 0, 22, newcomm, MPI_STATUS_IGNORE);
+		ret = starpu_mpi_recv(data[0], 0, 22, newcomm, MPI_STATUS_IGNORE);
+		STARPU_CHECK_RETURN_VALUE(ret, "starpu_mpi_recv");
 		starpu_data_acquire(data[0], STARPU_R);
 		xx = (int *)starpu_variable_get_local_ptr(data[0]);
 		FPRINTF(stderr, "[%d][%d] received %d\n", rank, newrank, *xx);
@@ -141,25 +151,29 @@ int main(int argc, char **argv)
 		starpu_data_acquire(data[2], STARPU_R);
 		int rvalue = *((int *)starpu_variable_get_local_ptr(data[2]));
 		starpu_data_release(data[2]);
-		FPRINTF_MPI(stderr, "sending value %d to %d and receiving from %d\n", rvalue, 1, size-1);
-		starpu_mpi_send(data[2], 1, 44, MPI_COMM_WORLD);
-		starpu_mpi_recv(data[2], size-1, 44, MPI_COMM_WORLD, MPI_STATUS_IGNORE);
+		FPRINTF_MPI_COMM(stderr, MPI_COMM_WORLD, "sending value %d to %d and receiving from %d\n", rvalue, 1, size-1);
+		ret = starpu_mpi_send(data[2], 1, 44, MPI_COMM_WORLD);
+		STARPU_CHECK_RETURN_VALUE(ret, "starpu_mpi_send");
+		ret = starpu_mpi_recv(data[2], size-1, 44, MPI_COMM_WORLD, MPI_STATUS_IGNORE);
+		STARPU_CHECK_RETURN_VALUE(ret, "starpu_mpi_recv");
 		starpu_data_acquire(data[2], STARPU_R);
 		int *xx = (int *)starpu_variable_get_local_ptr(data[2]);
-		FPRINTF_MPI(stderr, "Value back is %d\n", *xx);
+		FPRINTF_MPI_COMM(stderr, MPI_COMM_WORLD, "Value back is %d\n", *xx);
 		STARPU_ASSERT_MSG(*xx == rvalue + (2*(size-1)), "Received value %d is incorrect (should be %d)\n", *xx, rvalue + (2*(size-1)));
 		starpu_data_release(data[2]);
 	}
 	else
 	{
 		int next = (rank == size-1) ? 0 : rank+1;
-		starpu_mpi_recv(data[2], rank-1, 44, MPI_COMM_WORLD, MPI_STATUS_IGNORE);
+		ret = starpu_mpi_recv(data[2], rank-1, 44, MPI_COMM_WORLD, MPI_STATUS_IGNORE);
+		STARPU_CHECK_RETURN_VALUE(ret, "starpu_mpi_recv");
 		starpu_data_acquire(data[2], STARPU_RW);
 		int *xx = (int *)starpu_variable_get_local_ptr(data[2]);
-		FPRINTF_MPI(stderr, "receiving %d from %d and sending %d to %d\n", *xx, rank-1, *xx+2, next);
+		FPRINTF_MPI_COMM(stderr, MPI_COMM_WORLD, "receiving %d from %d and sending %d to %d\n", *xx, rank-1, *xx+2, next);
 		*xx = *xx + 2;
 		starpu_data_release(data[2]);
-		starpu_mpi_send(data[2], next, 44, MPI_COMM_WORLD);
+		ret = starpu_mpi_send(data[2], next, 44, MPI_COMM_WORLD);
+		STARPU_CHECK_RETURN_VALUE(ret, "starpu_mpi_send");
 	}
 
 	if (newrank == 0 || newrank == 1)
@@ -178,6 +192,6 @@ int main(int argc, char **argv)
 
 	starpu_mpi_shutdown();
 	MPI_Comm_free(&newcomm);
-        MPI_Finalize();
+	MPI_Finalize();
 	return 0;
 }
