@@ -1,7 +1,7 @@
 /* StarPU --- Runtime system for heterogeneous multicore architectures.
  *
- * Copyright (C) 2010-2021  Université de Bordeaux, CNRS (LaBRI UMR 5800), Inria
- * Copyright (C) 2013       Thibaut Lambert
+ * Copyright (C) 2010-2025  University of Bordeaux, CNRS (LaBRI UMR 5800), Inria
+ * Copyright (C) 2013-2013  Thibaut Lambert
  *
  * StarPU is free software; you can redistribute it and/or modify
  * it under the terms of the GNU Lesser General Public License as published by
@@ -30,6 +30,10 @@
 #include <numaif.h>
 #endif
 
+#ifdef STARPU_HAVE_VALGRIND_H
+#include <valgrind/valgrind.h>
+#endif
+
 static unsigned long size = 4096;
 static unsigned nblocks = 16;
 static unsigned check = 0;
@@ -434,7 +438,7 @@ int main(int argc, char **argv)
 	int rank;
 	int world_size;
 	int ret;
-	unsigned i, j;
+	unsigned i, j, k;
 
 	/*
 	 *	Initialization
@@ -450,9 +454,6 @@ int main(int argc, char **argv)
 	if (thread_support < MPI_THREAD_FUNNELED)
 		fprintf(stderr,"Warning: MPI does not have thread support!\n");
 
-	starpu_mpi_comm_rank(MPI_COMM_WORLD, &rank);
-	starpu_mpi_comm_size(MPI_COMM_WORLD, &world_size);
-
 	starpu_srand48((long int)time(NULL));
 
 	parse_args(rank, argc, argv);
@@ -460,6 +461,9 @@ int main(int argc, char **argv)
 	ret = starpu_mpi_init_conf(NULL, NULL, 0, MPI_COMM_WORLD, NULL);
 	STARPU_CHECK_RETURN_VALUE(ret, "starpu_mpi_init_conf");
 
+	starpu_mpi_comm_rank(MPI_COMM_WORLD, &rank);
+	starpu_mpi_comm_size(MPI_COMM_WORLD, &world_size);
+
 	/* We disable sequential consistency in this example */
 	starpu_data_set_default_sequential_consistency_flag(0);
 
@@ -478,15 +482,15 @@ int main(int argc, char **argv)
 	STARPU_ASSERT(barrier_ret == MPI_SUCCESS);
 
 	/*
-	 * 	Problem Init
+	 *	Problem Init
 	 */
 
 	init_matrix(rank);
 
 	fprintf(stderr, "Rank %d: allocated (%d + %d) MB = %d MB\n", rank,
-                        (int)(allocated_memory/(1024*1024)),
+			(int)(allocated_memory/(1024*1024)),
 			(int)(allocated_memory_extra/(1024*1024)),
-                        (int)((allocated_memory+allocated_memory_extra)/(1024*1024)));
+			(int)((allocated_memory+allocated_memory_extra)/(1024*1024)));
 
 	display_grid(rank, nblocks);
 
@@ -527,7 +531,7 @@ int main(int argc, char **argv)
 	double timing = STARPU_PLU(plu_main)(nblocks, rank, world_size, no_prio);
 
 	/*
-	 * 	Report performance
+	 *	Report performance
 	 */
 
 	int reduce_ret;
@@ -600,30 +604,94 @@ int main(int argc, char **argv)
 	}
 
 	/*
-	 * 	Termination
+	 *	Termination
 	 */
+	size_t blocksize = (size_t)(size/nblocks)*(size/nblocks)*sizeof(TYPE);
 	for (j = 0; j < nblocks; j++)
 	{
 		for (i = 0; i < nblocks; i++)
 		{
-			starpu_data_unregister(dataA_handles[j+nblocks*i]);
+			starpu_data_handle_t handle = dataA_handles[j+nblocks*i];
+			if (handle != STARPU_POISON_PTR)
+				starpu_data_unregister(handle);
 			TYPE *blockptr = dataA[j+i*nblocks];
 			if (blockptr != STARPU_POISON_PTR)
-				starpu_free(blockptr);
+				starpu_free_noflag(blockptr, blocksize);
 		}
 	}
 	free(dataA_handles);
 	free(dataA);
 
+#ifdef SINGLE_TMP11
+	starpu_data_unregister(tmp_11_block_handle);
+	starpu_free_noflag(tmp_11_block, blocksize);
+#else
+	for (k = 0; k < nblocks; k++)
+	{
+		if (tmp_11_block_is_needed(rank, nblocks, k))
+		{
+			starpu_data_unregister(tmp_11_block_handles[k]);
+			starpu_free_noflag(tmp_11_block[k], blocksize);
+		}
+	}
+	free(tmp_11_block_handles);
+	free(tmp_11_block);
+#endif
+
+	for (k = 0; k < nblocks; k++)
+	{
+#ifdef SINGLE_TMP1221
+		if (tmp_12_block_is_needed(rank, nblocks, k))
+		{
+			starpu_data_unregister(tmp_12_block_handles);
+			starpu_free_noflag(tmp_12_block[k], blocksize);
+		}
+
+		if (tmp_21_block_is_needed(rank, nblocks, k))
+		{
+			starpu_data_unregister(tmp_21_block_handles[k]);
+			starpu_free_noflag(tmp_21_block[k], blocksize);
+		}
+#else
+	for (i = 0; i < 2; i++)
+	{
+		if (tmp_12_block_is_needed(rank, nblocks, k))
+		{
+			starpu_data_unregister(tmp_12_block_handles[i][k]);
+			starpu_free_noflag(tmp_12_block[i][k], blocksize);
+		}
+
+		if (tmp_21_block_is_needed(rank, nblocks, k))
+		{
+			starpu_data_unregister(tmp_21_block_handles[i][k]);
+			starpu_free_noflag(tmp_21_block[i][k], blocksize);
+		}
+	}
+#endif
+	}
+
+#ifdef SINGLE_TMP1221
+	free(tmp_12_block_handles);
+	free(tmp_21_block_handles);
+	free(tmp_12_block);
+	free(tmp_21_block);
+#else
+	for (i = 0; i < 2; i++)
+	{
+		free(tmp_12_block_handles[i]);
+		free(tmp_21_block_handles[i]);
+		free(tmp_12_block[i]);
+		free(tmp_21_block[i]);
+	}
+#endif
+
 	barrier_ret = MPI_Barrier(MPI_COMM_WORLD);
 	STARPU_ASSERT(barrier_ret == MPI_SUCCESS);
 
 	starpu_cublas_shutdown();
 	starpu_mpi_shutdown();
 
-#if 0
 	MPI_Finalize();
-#endif
 
 	return 0;
 }
