@@ -1,6 +1,6 @@
 /* StarPU --- Runtime system for heterogeneous multicore architectures.
  *
- * Copyright (C) 2009-2020  Université de Bordeaux, CNRS (LaBRI UMR 5800), Inria
+ * Copyright (C) 2009-2025  University of Bordeaux, CNRS (LaBRI UMR 5800), Inria
  *
  * StarPU is free software; you can redistribute it and/or modify
  * it under the terms of the GNU Lesser General Public License as published by
@@ -27,6 +27,16 @@
 #include <mpi/starpu_mpi_comm.h>
 #include <mpi/starpu_mpi_tag.h>
 #include <mpi/starpu_mpi_driver.h>
+#include <mpi/starpu_mpi_mpi.h>
+
+static void starpu_mpi_mpi_backend_constructor(void) __attribute__((constructor));
+static void starpu_mpi_mpi_backend_constructor(void)
+{
+#ifdef HAVE_PIOMAN
+	/* We don't want progression in both PIOman and StarPU */
+	setenv("PIOM_ENABLE_PROGRESSION", "0", 0);
+#endif
+}
 
 void _starpu_mpi_mpi_backend_init(struct starpu_conf *conf)
 {
@@ -42,34 +52,32 @@ void _starpu_mpi_mpi_backend_shutdown(void)
 
 int _starpu_mpi_mpi_backend_reserve_core(void)
 {
-	return (starpu_get_env_number_default("STARPU_MPI_DRIVER_CALL_FREQUENCY", 0) <= 0);
+	return (starpu_getenv_number_default("STARPU_MPI_DRIVER_CALL_FREQUENCY", 0) <= 0);
 }
 
 void _starpu_mpi_mpi_backend_request_init(struct _starpu_mpi_req *req)
 {
 	_STARPU_MPI_CALLOC(req->backend, 1, sizeof(struct _starpu_mpi_req_backend));
 
-	req->backend->data_request = 0;
+	//req->backend->data_request = 0;
 
-	STARPU_PTHREAD_MUTEX_INIT(&req->backend->req_mutex, NULL);
-	STARPU_PTHREAD_COND_INIT(&req->backend->req_cond, NULL);
-	STARPU_PTHREAD_MUTEX_INIT(&req->backend->posted_mutex, NULL);
-	STARPU_PTHREAD_COND_INIT(&req->backend->posted_cond, NULL);
+	STARPU_PTHREAD_MUTEX_INIT0(&req->backend->req_mutex, NULL);
+	STARPU_PTHREAD_COND_INIT0(&req->backend->req_cond, NULL);
+	STARPU_PTHREAD_COND_INIT0(&req->backend->posted_cond, NULL);
 
-	req->backend->other_request = NULL;
+	//req->backend->other_request = NULL;
 
-	req->backend->size_req = 0;
-	req->backend->internal_req = NULL;
-	req->backend->is_internal_req = 0;
+	//req->backend->size_req = 0;
+	//req->backend->internal_req = NULL;
+	//req->backend->is_internal_req = 0;
 	req->backend->to_destroy = 1;
-	req->backend->early_data_handle = NULL;
-	req->backend->envelope = NULL;
+	//req->backend->early_data_handle = NULL;
+	//req->backend->envelope = NULL;
 }
 
-void _starpu_mpi_mpi_backend_request_fill(struct _starpu_mpi_req *req, MPI_Comm comm, int is_internal_req)
+void _starpu_mpi_mpi_backend_request_fill(struct _starpu_mpi_req *req, int is_internal_req)
 {
-	_starpu_mpi_comm_register(comm);
-
+	_starpu_mpi_comm_register(req->node_tag.node.comm);
 	req->backend->is_internal_req = is_internal_req;
 	/* For internal requests, we wait for both the request completion and the matching application request completion */
 	req->backend->to_destroy = !is_internal_req;
@@ -79,9 +87,9 @@ void _starpu_mpi_mpi_backend_request_destroy(struct _starpu_mpi_req *req)
 {
 	STARPU_PTHREAD_MUTEX_DESTROY(&req->backend->req_mutex);
 	STARPU_PTHREAD_COND_DESTROY(&req->backend->req_cond);
-	STARPU_PTHREAD_MUTEX_DESTROY(&req->backend->posted_mutex);
 	STARPU_PTHREAD_COND_DESTROY(&req->backend->posted_cond);
 	free(req->backend);
+	req->backend = NULL;
 }
 
 void _starpu_mpi_mpi_backend_data_clear(starpu_data_handle_t data_handle)
@@ -101,15 +109,29 @@ void _starpu_mpi_mpi_backend_comm_register(MPI_Comm comm)
 
 struct _starpu_mpi_backend _mpi_backend =
 {
- 	._starpu_mpi_backend_init = _starpu_mpi_mpi_backend_init,
- 	._starpu_mpi_backend_shutdown = _starpu_mpi_mpi_backend_shutdown,
+	._starpu_mpi_backend_init = _starpu_mpi_mpi_backend_init,
+	._starpu_mpi_backend_shutdown = _starpu_mpi_mpi_backend_shutdown,
 	._starpu_mpi_backend_reserve_core = _starpu_mpi_mpi_backend_reserve_core,
 	._starpu_mpi_backend_request_init = _starpu_mpi_mpi_backend_request_init,
 	._starpu_mpi_backend_request_fill = _starpu_mpi_mpi_backend_request_fill,
 	._starpu_mpi_backend_request_destroy = _starpu_mpi_mpi_backend_request_destroy,
 	._starpu_mpi_backend_data_clear = _starpu_mpi_mpi_backend_data_clear,
 	._starpu_mpi_backend_data_register = _starpu_mpi_mpi_backend_data_register,
-	._starpu_mpi_backend_comm_register = _starpu_mpi_mpi_backend_comm_register
+	._starpu_mpi_backend_comm_register = _starpu_mpi_mpi_backend_comm_register,
+
+	._starpu_mpi_backend_progress_init = _starpu_mpi_progress_init,
+	._starpu_mpi_backend_progress_shutdown = _starpu_mpi_progress_shutdown,
+#ifdef STARPU_SIMGRID
+	._starpu_mpi_backend_wait_for_initialization = _starpu_mpi_wait_for_initialization,
+#endif
+
+	._starpu_mpi_backend_barrier = _starpu_mpi_barrier,
+	._starpu_mpi_backend_wait_for_all = _starpu_mpi_wait_for_all,
+	._starpu_mpi_backend_wait = _starpu_mpi_wait,
+	._starpu_mpi_backend_test = _starpu_mpi_test,
+
+	._starpu_mpi_backend_isend_size_func = _starpu_mpi_isend_size_func,
+	._starpu_mpi_backend_irecv_size_func = _starpu_mpi_irecv_size_func,
 };
 
 #endif /* STARPU_USE_MPI_MPI*/
