@@ -1,6 +1,6 @@
 /* StarPU --- Runtime system for heterogeneous multicore architectures.
  *
- * Copyright (C) 2014-2021  Université de Bordeaux, CNRS (LaBRI UMR 5800), Inria
+ * Copyright (C) 2014-2025  University of Bordeaux, CNRS (LaBRI UMR 5800), Inria
  *
  * StarPU is free software; you can redistribute it and/or modify
  * it under the terms of the GNU Lesser General Public License as published by
@@ -90,6 +90,10 @@ int _starpu_mpi_select_node_with_most_data(int me, int nb_nodes, struct starpu_d
 		int rank = starpu_data_get_rank(data);
 		size_t size = data->ops->get_size(data);
 
+		if (rank == STARPU_MPI_PER_NODE)
+			/* Each of them has it */
+			continue;
+
 		if (mode & STARPU_R)
 			size_on_nodes[rank] += size;
 
