@@ -1,6 +1,6 @@
 /* StarPU --- Runtime system for heterogeneous multicore architectures.
  *
- * Copyright (C) 2011-2020  Université de Bordeaux, CNRS (LaBRI UMR 5800), Inria
+ * Copyright (C) 2011-2025  University of Bordeaux, CNRS (LaBRI UMR 5800), Inria
  *
  * StarPU is free software; you can redistribute it and/or modify
  * it under the terms of the GNU Lesser General Public License as published by
@@ -56,18 +56,25 @@ int my_distrib(int x, int nb_nodes)
 	return x % nb_nodes;
 }
 
-void dotest(int rank, int size, char *enabled)
+void dotest(int rank, int size, starpu_mpi_tag_t initial_tag, char *enabled)
 {
 	int x, i;
 	int ret;
 	unsigned values[X];
 	starpu_data_handle_t data_handles[X];
+	struct starpu_conf conf;
 
 	setenv("STARPU_MPI_CACHE", enabled, 1);
 
 	FPRINTF(stderr, "Testing with cache '%s'\n", enabled);
 
-	ret = starpu_mpi_init_conf(NULL, NULL, 0, MPI_COMM_WORLD, NULL);
+	starpu_conf_init(&conf);
+	starpu_conf_noworker(&conf);
+	conf.ncpus = -1;
+	conf.nmpi_ms = -1;
+	conf.ntcpip_ms = -1;
+
+	ret = starpu_mpi_init_conf(NULL, NULL, 0, MPI_COMM_WORLD, &conf);
 	STARPU_CHECK_RETURN_VALUE(ret, "starpu_mpi_init_conf");
 
 	for(x = 0; x < X; x++)
@@ -89,7 +96,7 @@ void dotest(int rank, int size, char *enabled)
 		}
 		if (data_handles[x])
 		{
-			starpu_mpi_data_register(data_handles[x], x, mpi_rank);
+			starpu_mpi_data_register(data_handles[x], initial_tag+x, mpi_rank);
 		}
 	}
 
@@ -103,7 +110,8 @@ void dotest(int rank, int size, char *enabled)
 	{
 		// Calling starpu_mpi_get_data_on_all_nodes_detached() is necessary to make sure all nodes have a valid copy of the data
 		starpu_mpi_get_data_on_all_nodes_detached(MPI_COMM_WORLD, data_handles[i]);
-		starpu_task_insert(&mycodelet2, STARPU_RW, data_handles[i], 0);
+		ret = starpu_task_insert(&mycodelet2, STARPU_RW, data_handles[i], 0);
+		STARPU_CHECK_RETURN_VALUE(ret, "starpu_task_insert");
 	}
 
 	starpu_task_wait_for_all();
@@ -120,13 +128,27 @@ void dotest(int rank, int size, char *enabled)
 int main(int argc, char **argv)
 {
 	int rank, size;
+	int barrier_ret;
+	starpu_mpi_tag_t initial_tag = 0;
 
 	MPI_INIT_THREAD_real(&argc, &argv, MPI_THREAD_SERIALIZED);
-	starpu_mpi_comm_rank(MPI_COMM_WORLD, &rank);
-	starpu_mpi_comm_size(MPI_COMM_WORLD, &size);
+	MPI_Comm_rank(MPI_COMM_WORLD, &rank);
+	MPI_Comm_size(MPI_COMM_WORLD, &size);
 
-	dotest(rank, size, "0");
-	dotest(rank, size, "1");
+	dotest(rank, size, initial_tag, "0");
+	initial_tag += X;
+
+	/* Be sure all nodes finished the dotest function before repeating it.
+	 * This is required by the dynamic broadcasts of StarPU-nmad:
+	 * initialization and release of dynamic broadcasts are made when
+	 * calling starpu_mpi_init() and starpu_mpi_shutdown() respectively,
+	 * but the restart of the dynamic broadcast component can create
+	 * deadlocks if the second test starts on a node before the first one
+	 * finishes on other nodes. */
+	barrier_ret = MPI_Barrier(MPI_COMM_WORLD);
+	STARPU_ASSERT(barrier_ret == MPI_SUCCESS);
+
+	dotest(rank, size, initial_tag, "1");
 
 	MPI_Finalize();
 	return 0;
