@@ -1,6 +1,6 @@
 /* StarPU --- Runtime system for heterogeneous multicore architectures.
  *
- * Copyright (C) 2010-2021  Université de Bordeaux, CNRS (LaBRI UMR 5800), Inria
+ * Copyright (C) 2009-2025  University of Bordeaux, CNRS (LaBRI UMR 5800), Inria
  *
  * StarPU is free software; you can redistribute it and/or modify
  * it under the terms of the GNU Lesser General Public License as published by
@@ -65,18 +65,21 @@ int main(int argc, char **argv)
 
 		if ((loop % 2) == (rank%2))
 		{
-			starpu_mpi_isend(tab_handle, &req, other_rank, loop, MPI_COMM_WORLD);
+			ret = starpu_mpi_isend(tab_handle, &req, other_rank, loop, MPI_COMM_WORLD);
+			STARPU_CHECK_RETURN_VALUE(ret, "starpu_mpi_isend");
 		}
 		else
 		{
-			starpu_mpi_irecv(tab_handle, &req, other_rank, loop, MPI_COMM_WORLD);
+			ret = starpu_mpi_irecv(tab_handle, &req, other_rank, loop, MPI_COMM_WORLD);
+			STARPU_CHECK_RETURN_VALUE(ret, "starpu_mpi_irecv");
 		}
 
 		int finished = 0;
 		do
 		{
 			MPI_Status status;
-			starpu_mpi_test(&req, &finished, &status);
+			ret = starpu_mpi_test(&req, &finished, &status);
+			STARPU_CHECK_RETURN_VALUE(ret, "starpu_mpi_test");
 #ifdef STARPU_SIMGRID
 			starpu_sleep(0.001);
 #endif
