@@ -1,6 +1,6 @@
 /* StarPU --- Runtime system for heterogeneous multicore architectures.
  *
- * Copyright (C) 2008-2023  Université de Bordeaux, CNRS (LaBRI UMR 5800), Inria
+ * Copyright (C) 2008-2025  University of Bordeaux, CNRS (LaBRI UMR 5800), Inria
  *
  * StarPU is free software; you can redistribute it and/or modify
  * it under the terms of the GNU Lesser General Public License as published by
@@ -374,6 +374,10 @@ int _starpu_generate_paje_trace_read_option(const char *option, struct starpu_fx
 	{
 		options->number_events_path = strdup("number_events.data");
 	}
+	else if (strcmp(option, "-use-task-color") == 0)
+	{
+		options->use_task_color = 1;
+	}
 	else
 	{
 		return 1;
@@ -482,6 +486,14 @@ void starpu_fxt_trace_user_event(unsigned long code STARPU_ATTRIBUTE_UNUSED)
 #endif
 }
 
+
+void starpu_fxt_trace_user_meta_string(const char *s STARPU_ATTRIBUTE_UNUSED)
+{
+#ifdef STARPU_USE_FXT
+	_STARPU_TRACE_META(s);
+#endif
+}
+
 void starpu_fxt_trace_user_event_string(const char *s STARPU_ATTRIBUTE_UNUSED)
 {
 #ifdef STARPU_USE_FXT
