@@ -1,6 +1,6 @@
 /* StarPU --- Runtime system for heterogeneous multicore architectures.
  *
- * Copyright (C) 2008-2021  Université de Bordeaux, CNRS (LaBRI UMR 5800), Inria
+ * Copyright (C) 2008-2025  University of Bordeaux, CNRS (LaBRI UMR 5800), Inria
  *
  * StarPU is free software; you can redistribute it and/or modify
  * it under the terms of the GNU Lesser General Public License as published by
@@ -146,7 +146,7 @@ static void _starpu_tag_free(void *_tag)
 }
 
 /*
- * Staticly initializing tag_global_rwlock seems to lead to weird errors
+ * Statically initializing tag_global_rwlock seems to lead to weird errors
  * on Darwin, so we do it dynamically.
  */
 void _starpu_init_tags(void)
@@ -174,14 +174,14 @@ void starpu_tag_remove(starpu_tag_t id)
 	}
 }
 
-void _starpu_tag_clear(void)
+void starpu_tag_clear(void)
 {
 	STARPU_PTHREAD_RWLOCK_WRLOCK(&tag_global_rwlock);
 
 	/* XXX: _starpu_tag_free takes the tag spinlocks while we are keeping
 	 * the global rwlock. This contradicts the lock order of
 	 * starpu_tag_wait_array. Should not be a problem in practice since
-	 * _starpu_tag_clear is called at shutdown only. */
+	 * starpu_tag_clear is called at shutdown only. */
 	struct _starpu_tag_table *entry=NULL, *tmp=NULL;
 
 	HASH_ITER(hh, tag_htbl, entry, tmp)
