@@ -1,7 +1,7 @@
 /* StarPU --- Runtime system for heterogeneous multicore architectures.
  *
- * Copyright (C) 2009-2024  Université de Bordeaux, CNRS (LaBRI UMR 5800), Inria
- * Copyright (C) 2013       Corentin Salingue
+ * Copyright (C) 2009-2025  University of Bordeaux, CNRS (LaBRI UMR 5800), Inria
+ * Copyright (C) 2013-2013  Corentin Salingue
  *
  * StarPU is free software; you can redistribute it and/or modify
  * it under the terms of the GNU Lesser General Public License as published by
@@ -51,7 +51,9 @@
 #ifdef STARPU_HAVE_HWLOC
 #include <hwloc.h>
 #ifdef STARPU_HAVE_NVML_H
+#undef  nvmlDeviceGetPciInfo
 #define nvmlDeviceGetPciInfo _starpu_nvmlDeviceGetPciInfo
+#undef  nvmlDeviceGetUUID
 #define nvmlDeviceGetUUID _starpu_nvmlDeviceGetUUID
 #include <hwloc/nvml.h>
 #endif
@@ -1123,7 +1125,7 @@ static void write_bus_affinity_file_content(void)
 	}
 
 	if (locked)
-		_starpu_frdunlock(f);
+		_starpu_fwrunlock(f);
 	fclose(f);
 }
 
@@ -3247,6 +3249,16 @@ double starpu_transfer_predict(unsigned src_node, unsigned dst_node, size_t size
 	}
 #endif
 
+	if (isnan(latency) || isnan(bandwidth))
+	{
+		static int warned = 0;
+		if (!warned)
+		{
+			_STARPU_DISP("Warning: no bus performance model was calibrated between nodes %d and %d, ignoring transfer time\n", src_node, dst_node);
+			warned = 1;
+		}
+		return 0;
+	}
 
 	return latency + (size/bandwidth)*2*ngpus;
 }
