@@ -1,9 +1,9 @@
 /* StarPU --- Runtime system for heterogeneous multicore architectures.
  *
- * Copyright (C) 2008-2023  Université de Bordeaux, CNRS (LaBRI UMR 5800), Inria
- * Copyright (C) 2013       Simon Archipoff
- * Copyright (C) 2013       Thibaut Lambert
- * Copyright (C) 2016       Uppsala University
+ * Copyright (C) 2008-2025  University of Bordeaux, CNRS (LaBRI UMR 5800), Inria
+ * Copyright (C) 2016-2016  Uppsala University
+ * Copyright (C) 2013-2013  Thibaut Lambert
+ * Copyright (C) 2013-2013  Simon Archipoff
  *
  * StarPU is free software; you can redistribute it and/or modify
  * it under the terms of the GNU Lesser General Public License as published by
@@ -72,6 +72,10 @@ static struct starpu_sched_policy *predefined_policies[] =
 	&_starpu_sched_modular_parallel_random_policy,
 	&_starpu_sched_modular_parallel_random_prio_policy,
 	&_starpu_sched_modular_ws_policy,
+	&_starpu_sched_modular_dmda_policy,
+	&_starpu_sched_modular_dmdap_policy,
+	&_starpu_sched_modular_dmdar_policy,
+	&_starpu_sched_modular_dmdas_policy,
 	&_starpu_sched_modular_heft_policy,
 	&_starpu_sched_modular_heft_prio_policy,
 	&_starpu_sched_modular_heft2_policy,
