@@ -1,7 +1,7 @@
 /* StarPU --- Runtime system for heterogeneous multicore architectures.
  *
- * Copyright (C) 2010, 2012-2015  Université de Bordeaux
- * Copyright (C) 2010, 2011, 2013, 2015  CNRS
+ * Copyright (C) 2008-2025  University of Bordeaux, CNRS (LaBRI UMR 5800), Inria
+ * Copyright (C) 2021-2021  Federal University of Rio Grande do Sul (UFRGS)
  *
  * StarPU is free software; you can redistribute it and/or modify
  * it under the terms of the GNU Lesser General Public License as published by
@@ -18,20 +18,16 @@
 #ifndef __COPY_DRIVER_H__
 #define __COPY_DRIVER_H__
 
+/** @file */
+
 #ifdef HAVE_AIO_H
 #include <aio.h>
 #endif
 
 #include <common/config.h>
+#include <common/list.h>
 
-#ifdef STARPU_USE_CUDA
-#include <cuda.h>
-#include <cuda_runtime.h>
-#endif
-
-#ifdef STARPU_USE_OPENCL
-#include <starpu_opencl.h>
-#endif
+#pragma GCC visibility push(hidden)
 
 #ifdef __cplusplus
 extern "C"
@@ -41,52 +37,46 @@ extern "C"
 struct _starpu_data_request;
 struct _starpu_data_replicate;
 
-#ifdef STARPU_USE_MIC
-/* MIC needs memory_node to know which MIC is concerned.
- * mark is used to wait asynchronous request.
- * signal is used to test asynchronous request. */
-struct _starpu_mic_async_event
+enum _starpu_may_alloc
 {
-	unsigned memory_node;
-	int mark;
-	uint64_t *signal;
+	_STARPU_DATAWIZARD_DO_NOT_ALLOC,
+	_STARPU_DATAWIZARD_DO_ALLOC,
+	_STARPU_DATAWIZARD_ONLY_FAST_ALLOC
 };
-#endif
 
-struct _starpu_disk_async_event
-{
-	unsigned memory_node;
+
+LIST_TYPE(_starpu_disk_backend_event,
 	void *backend_event;
+);
+
+struct _starpu_disk_event
+{
+	unsigned memory_node;
+	unsigned node;
+	struct _starpu_disk_backend_event_list * requests;
+
+	void * ptr;
+	size_t size;
+	starpu_data_handle_t handle;
 };
 
-/* this is a structure that can be queried to see whether an asynchronous
+/** this is a structure that can be queried to see whether an asynchronous
  * transfer has terminated or not */
 union _starpu_async_channel_event
 {
-#ifdef STARPU_SIMGRID
-	struct
-	{
-		unsigned finished;
-		starpu_pthread_mutex_t mutex;
-		starpu_pthread_cond_t cond;
-	};
-#endif
-#ifdef STARPU_USE_CUDA
-	cudaEvent_t cuda_event;
-#endif
-#ifdef STARPU_USE_OPENCL
-        cl_event opencl_event;
-#endif
-#ifdef STARPU_USE_MIC
-	struct _starpu_mic_async_event mic_event;
-#endif
-	struct _starpu_disk_async_event disk_event;
+	char data[40];
 };
 
 struct _starpu_async_channel
 {
 	union _starpu_async_channel_event event;
-	enum starpu_node_kind type;
+	const struct _starpu_node_ops *node_ops;
+	/** Which node to polling when needing ACK msg */
+	struct _starpu_mp_node *polling_node_sender;
+	struct _starpu_mp_node *polling_node_receiver;
+	/** Used to know if the acknowlegdment msg is arrived from sinks */
+	volatile int starpu_mp_common_finished_sender;
+	volatile int starpu_mp_common_finished_receiver;
 };
 
 void _starpu_wake_all_blocked_workers_on_node(unsigned nodeid);
@@ -96,14 +86,21 @@ int _starpu_driver_copy_data_1_to_1(starpu_data_handle_t handle,
 				    struct _starpu_data_replicate *dst_replicate,
 				    unsigned donotread,
 				    struct _starpu_data_request *req,
-				    unsigned may_alloc,
-				    unsigned prefetch);
+				    enum _starpu_may_alloc may_alloc,
+				    enum starpu_is_prefetch prefetch);
 
+int _starpu_copy_interface_any_to_any(starpu_data_handle_t handle, void *src_interface, unsigned src_node, void *dst_interface, unsigned dst_node, struct _starpu_data_request *req);
+
+/* Just test for request completion */
 unsigned _starpu_driver_test_request_completion(struct _starpu_async_channel *async_channel);
+
+/* Wait for request completion. Only used at starpu_shutdown */
 void _starpu_driver_wait_request_completion(struct _starpu_async_channel *async_channel);
 
 #ifdef __cplusplus
 }
 #endif
 
+#pragma GCC visibility pop
+
 #endif // __COPY_DRIVER_H__
