@@ -1,7 +1,7 @@
 /* StarPU --- Runtime system for heterogeneous multicore architectures.
  *
- * Copyright (C) 2010-2021  Université de Bordeaux, CNRS (LaBRI UMR 5800), Inria
- * Copyright (C) 2020       Federal University of Rio Grande do Sul (UFRGS)
+ * Copyright (C) 2009-2025  University of Bordeaux, CNRS (LaBRI UMR 5800), Inria
+ * Copyright (C) 2020-2020  Federal University of Rio Grande do Sul (UFRGS)
  *
  * StarPU is free software; you can redistribute it and/or modify
  * it under the terms of the GNU Lesser General Public License as published by
@@ -25,29 +25,32 @@
 #include <starpu_util.h>
 #include <common/config.h>
 
+#pragma GCC visibility push(hidden)
+
+enum _starpu_worker_status_index;
+
+extern int _starpu_codelet_profiling;
+extern int _starpu_energy_profiling;
+
 /** Create a task profiling info structure (with the proper time stamps) in case
  * profiling is enabled. */
 struct starpu_profiling_task_info *_starpu_allocate_profiling_info_if_needed(struct starpu_task *task);
 
 /** Update the per-worker profiling info after a task (or more) was executed.
  * This tells StarPU how much time was spent doing computation. */
-void _starpu_worker_update_profiling_info_executing(int workerid, struct timespec *executing_time, int executed_tasks, uint64_t used_cycles, uint64_t stall_cycles, double consumed_energy, double flops);
+void _starpu_worker_update_profiling_info_executing(int workerid, int executed_tasks, uint64_t used_cycles, uint64_t stall_cycles, double consumed_energy, double flops);
 
-/** Record the date when the worker started to sleep. This permits to measure
- * how much time was spent sleeping. */
-void _starpu_worker_restart_sleeping(int workerid);
+/** Record the date when the worker entered this state. This permits to measure
+ * how much time was spent in this state.
+ * start_time is optional, if unspecified, _starpu_worker_start_state will just
+ * take the current time. */
+void _starpu_worker_start_state(int workerid, enum _starpu_worker_status_index index, struct timespec *start_time);
 
-/** Record the date when the worker stopped sleeping. This permits to measure
- * how much time was spent sleeping. */
-void _starpu_worker_stop_sleeping(int workerid);
-
-/** Record the date when the worker started to execute a piece of code. This
- * permits to measure how much time was really spent doing computation at the
- * end of the codelet. */
-void _starpu_worker_register_executing_start_date(int workerid, struct timespec *executing_start);
-
-/** Record that the worker is not executing any more. */
-void _starpu_worker_register_executing_end(int workerid);
+/* Record the date when the worker left this state. This permits to measure
+ * how much time was spent in this state.
+ * stop_time is optional, if unspecified, _starpu_worker_start_state will just
+ * take the current time. */
+void _starpu_worker_stop_state(int workerid, enum _starpu_worker_status_index index, struct timespec *stop_time);
 
 /** When StarPU is initialized, a matrix describing all the bus between memory
  * nodes is created: it indicates whether there is a physical link between two
@@ -67,6 +70,12 @@ void _starpu_bus_update_profiling_info(int src_node, int dst_node, size_t size);
 void _starpu_profiling_set_task_push_start_time(struct starpu_task *task);
 void _starpu_profiling_set_task_push_end_time(struct starpu_task *task);
 
+#ifdef STARPU_PAPI
+/** Functions for papi task profilling */
+void _starpu_profiling_papi_task_start_counters(struct starpu_task *task);
+void _starpu_profiling_papi_task_stop_counters(struct starpu_task *task);
+#endif
+
 /** This function needs to be called before other starpu_profile_* functions */
 void _starpu_profiling_init(void);
 
@@ -75,4 +84,6 @@ void _starpu_profiling_start(void);
 
 void _starpu_profiling_terminate(void);
 
+#pragma GCC visibility pop
+
 #endif // __PROFILING_H__
