@@ -1,6 +1,6 @@
 /* StarPU --- Runtime system for heterogeneous multicore architectures.
  *
- * Copyright (C) 2011-2021  Université de Bordeaux, CNRS (LaBRI UMR 5800), Inria
+ * Copyright (C) 2011-2025  University of Bordeaux, CNRS (LaBRI UMR 5800), Inria
  *
  * StarPU is free software; you can redistribute it and/or modify
  * it under the terms of the GNU Lesser General Public License as published by
@@ -72,15 +72,18 @@ static void opencl_task(void *buffers[], void *args)
 	unsigned i;
 	for (i = 0; i < size; i++)
 	{
-		clEnqueueWriteBuffer(queue,
-				numbers,
-				CL_TRUE,
-				i*sizeof(int),  /* offset */
-				sizeof(int),
-				&i,
-				0,              /* num_events_in_wait_list */
-				NULL,           /* event_wait_list */
-				NULL            /* event */);
+		cl_int err;
+		err = clEnqueueWriteBuffer(queue,
+					   numbers,
+					   CL_TRUE,
+					   i*sizeof(int),  /* offset */
+					   sizeof(int),
+					   &i,
+					   0,              /* num_events_in_wait_list */
+					   NULL,           /* event_wait_list */
+					   NULL            /* event */);
+		if (STARPU_UNLIKELY(err != CL_SUCCESS)) STARPU_OPENCL_REPORT_ERROR(err);
+
 	}
 }
 #endif
@@ -117,22 +120,19 @@ int main(int argc, char *argv[])
 	starpu_variable_data_register(&handle, STARPU_MAIN_RAM, (uintptr_t)pointer,
 				      sizeof(int));
 	STARPU_ASSERT(starpu_data_handle_to_pointer(handle, STARPU_MAIN_RAM) == pointer);
-	STARPU_ASSERT(starpu_data_pointer_is_inside(handle, STARPU_MAIN_RAM, pointer));
 	starpu_data_unregister(handle);
 
 	starpu_vector_data_register(&handle, STARPU_MAIN_RAM, (uintptr_t)pointer,
 				    count, sizeof(int));
 	STARPU_ASSERT(starpu_data_handle_to_pointer(handle, STARPU_MAIN_RAM) == pointer);
-	STARPU_ASSERT(starpu_data_pointer_is_inside(handle, STARPU_MAIN_RAM, pointer));
 	starpu_data_unregister(handle);
 
-	starpu_matrix_data_register(&handle, STARPU_MAIN_RAM, (uintptr_t)pointer, 0,
+	starpu_matrix_data_register(&handle, STARPU_MAIN_RAM, (uintptr_t)pointer, count,
 				    count, 1, sizeof(int));
 	STARPU_ASSERT(starpu_data_handle_to_pointer(handle, STARPU_MAIN_RAM) == pointer);
-	STARPU_ASSERT(starpu_data_pointer_is_inside(handle, STARPU_MAIN_RAM, pointer));
 	starpu_data_unregister(handle);
 
-	starpu_free(pointer);
+	starpu_free_noflag(pointer, count * sizeof(int));
 	pointer = NULL;
 
 	/* Lazy allocation.  */
@@ -146,7 +146,10 @@ int main(int argc, char *argv[])
 				 STARPU_VALUE, &count, sizeof(count),
 				 0);
 	if (err == -ENODEV)
-		return STARPU_TEST_SKIPPED;
+	{
+		ret = STARPU_TEST_SKIPPED;
+		goto out;
+	}
 
 	/* Acquire the handle, forcing a local allocation.  */
 	starpu_data_acquire(handle, STARPU_R);
@@ -165,7 +168,6 @@ int main(int argc, char *argv[])
 		for(i = 0; i < count; i++)
 		{
 			int *numbers = (int *)pointer;
-			STARPU_ASSERT(starpu_data_pointer_is_inside(handle, STARPU_MAIN_RAM, numbers));
 			if (numbers[i] != i)
 			{
 				FPRINTF(stderr, "Incorrect value numbers[%d] == %d should be %d\n", (int)i, numbers[i], (int)i);
@@ -173,8 +175,10 @@ int main(int argc, char *argv[])
 			}
 		}
 	}
+
 	starpu_data_release(handle);
 
+out:
 	starpu_data_unregister(handle);
 
 	starpu_shutdown();
