@@ -1,6 +1,6 @@
 /* StarPU --- Runtime system for heterogeneous multicore architectures.
  *
- * Copyright (C) 2011-2020  Université de Bordeaux, CNRS (LaBRI UMR 5800), Inria
+ * Copyright (C) 2011-2025  University of Bordeaux, CNRS (LaBRI UMR 5800), Inria
  *
  * StarPU is free software; you can redistribute it and/or modify
  * it under the terms of the GNU Lesser General Public License as published by
@@ -26,7 +26,6 @@ extern void test_multiformat_cuda_func(void *buffers[], void *args);
 #ifdef STARPU_USE_OPENCL
 extern void test_multiformat_opencl_func(void *buffers[], void *args);
 #endif
-void test_multiformat_mic_func(void *buffers[], void *args);
 
 static struct point array_of_structs[N_ELEMENTS];
 static struct point array_of_structs_dummy[N_ELEMENTS];
@@ -43,9 +42,10 @@ struct test_config multiformat_config =
 #ifdef STARPU_USE_OPENCL
 	.opencl_func   = test_multiformat_opencl_func,
 #endif
-	.cpu_func_name = "test_multiformat_mic_func",
 	.handle        = &multiformat_handle,
+	.ptr           = array_of_structs,
 	.dummy_handle  = &multiformat_dummy_handle,
+	.dummy_ptr     = array_of_structs_dummy,
 	.copy_failed   = SUCCESS,
 	.name          = "multiformat_interface"
 };
@@ -76,33 +76,6 @@ test_multiformat_cpu_func(void *buffers[], void *args)
 	FPRINTF(stderr, "\n");
 }
 
-void test_multiformat_mic_func(void *buffers[], void *args)
-{
-	STARPU_SKIP_IF_VALGRIND;
-
-	printf("MIC\n");
-
-	struct struct_of_arrays *soa;
-	int n, i;
-	int factor;
-
-	soa = (struct struct_of_arrays *) STARPU_MULTIFORMAT_GET_MIC_PTR(buffers[0]);
-	n = STARPU_MULTIFORMAT_GET_NX(buffers[0]);
-	factor = *(int *) args;
-
-	for (i = 0; i < n; i++)
-	{
-		FPRINTF(stderr, "(%d %d) [%d]", soa->x[i], soa->y[i], factor);
-		if (soa->x[i] != i * factor || soa->y[i] != i * factor)
-		{
-			multiformat_config.copy_failed = 1;
-		}
-		soa->x[i] = -soa->x[i];
-		soa->y[i] = -soa->y[i];
-	}
-	FPRINTF(stderr, "\n");
-}
-
 #ifdef STARPU_USE_CUDA
 extern struct starpu_codelet cpu_to_cuda_cl;
 extern struct starpu_codelet cuda_to_cpu_cl;
@@ -113,11 +86,6 @@ extern struct starpu_codelet cpu_to_opencl_cl;
 extern struct starpu_codelet opencl_to_cpu_cl;
 #endif
 
-#ifdef STARPU_USE_MIC
-extern struct starpu_codelet cpu_to_mic_cl;
-extern struct starpu_codelet mic_to_cpu_cl;
-#endif
-
 struct starpu_multiformat_data_interface_ops format_ops =
 {
 #ifdef STARPU_USE_CUDA
@@ -129,11 +97,6 @@ struct starpu_multiformat_data_interface_ops format_ops =
 	.opencl_elemsize = 2 * sizeof(float),
 	.cpu_to_opencl_cl = &cpu_to_opencl_cl,
 	.opencl_to_cpu_cl = &opencl_to_cpu_cl,
-#endif
-#ifdef STARPU_USE_MIC
-	.mic_elemsize = 2 * sizeof(float),
-	.cpu_to_mic_cl = &cpu_to_mic_cl,
-	.mic_to_cpu_cl = &mic_to_cpu_cl,
 #endif
 	.cpu_elemsize = sizeof(struct point),
 };
@@ -173,21 +136,24 @@ int main(int argc, char **argv)
 	int ret;
 	struct data_interface_test_summary summary;
 	struct starpu_conf conf;
+
 	starpu_conf_init(&conf);
+#if defined(STARPU_USE_CUDA0) || defined(STARPU_USE_CUDA1)
+	conf.ncuda = 0;
+#else
 	conf.ncuda = 2;
+#endif
 	conf.nopencl = 1;
-	conf.nmic = -1;
 
 	ret = starpu_initialize(&conf, &argc, &argv);
-	if (ret == -ENODEV || starpu_cpu_worker_get_count() == 0)
-		return STARPU_TEST_SKIPPED;
+	if (ret == -ENODEV) return STARPU_TEST_SKIPPED;
 	STARPU_CHECK_RETURN_VALUE(ret, "starpu_init");
 
 	register_data();
 
-	run_tests(&multiformat_config, &summary);
+	ret = run_tests(&multiformat_config, &summary);
 
-	data_interface_test_summary_print(stderr, &summary);
+	if (ret) data_interface_test_summary_print(stderr, &summary);
 
 	unregister_data();
 
