@@ -1,6 +1,6 @@
 /* StarPU --- Runtime system for heterogeneous multicore architectures.
  *
- * Copyright (C) 2010-2021  Université de Bordeaux, CNRS (LaBRI UMR 5800), Inria
+ * Copyright (C) 2010-2025  University of Bordeaux, CNRS (LaBRI UMR 5800), Inria
  *
  * StarPU is free software; you can redistribute it and/or modify
  * it under the terms of the GNU Lesser General Public License as published by
@@ -40,12 +40,15 @@ static void increment_opencl_kernel(void *descr[], void *cl_arg)
 		cl_mem d_token = (cl_mem)STARPU_VARIABLE_GET_PTR(descr[i]);
 		unsigned h_token;
 
+		cl_int err;
 		cl_command_queue queue;
 		starpu_opencl_get_current_queue(&queue);
 
-		clEnqueueReadBuffer(queue, d_token, CL_TRUE, 0, sizeof(unsigned), (void *)&h_token, 0, NULL, NULL);
+		err = clEnqueueReadBuffer(queue, d_token, CL_TRUE, 0, sizeof(unsigned), (void *)&h_token, 0, NULL, NULL);
+		if (STARPU_UNLIKELY(err != CL_SUCCESS)) STARPU_OPENCL_REPORT_ERROR(err);
 		h_token++;
-		clEnqueueWriteBuffer(queue, d_token, CL_TRUE, 0, sizeof(unsigned), (void *)&h_token, 0, NULL, NULL);
+		err = clEnqueueWriteBuffer(queue, d_token, CL_TRUE, 0, sizeof(unsigned), (void *)&h_token, 0, NULL, NULL);
+		if (STARPU_UNLIKELY(err != CL_SUCCESS)) STARPU_OPENCL_REPORT_ERROR(err);
 		clFinish(queue);
 	}
 }
@@ -98,7 +101,7 @@ static struct starpu_codelet increment_cl =
 #endif
 	.cpu_funcs = {increment_cpu_kernel},
 
-	/* starpu_task_get_current() doesn't work on MIC */
+	/* starpu_task_get_current() doesn't work on MPI Master Slave */
 	/*.cpu_funcs_name = {"increment_cpu_kernel"},*/
 	.nbuffers = STARPU_VARIABLE_NBUFFERS,
 };
@@ -148,24 +151,28 @@ int main(void)
 			STARPU_CHECK_RETURN_VALUE(ret, "starpu_task_submit");
 		}
 
-		starpu_task_insert(&increment_cl,
-				STARPU_RW, handle1,
-				0);
-		starpu_task_insert(&increment_cl,
-				STARPU_RW, handle1,
-				STARPU_RW, handle2,
-				0);
-		starpu_task_insert(&increment_cl,
-				STARPU_RW, handle1,
-				STARPU_RW, handle2,
-				STARPU_RW, handle3,
-				0);
-		starpu_task_insert(&increment_cl,
-				STARPU_RW, handle1,
-				STARPU_RW, handle2,
-				STARPU_RW, handle3,
-				STARPU_RW, handle4,
-				0);
+		ret = starpu_task_insert(&increment_cl,
+					 STARPU_RW, handle1,
+					 0);
+		STARPU_CHECK_RETURN_VALUE(ret, "starpu_task_insert");
+		ret = starpu_task_insert(&increment_cl,
+					 STARPU_RW, handle1,
+					 STARPU_RW, handle2,
+					 0);
+		STARPU_CHECK_RETURN_VALUE(ret, "starpu_task_insert");
+		ret = starpu_task_insert(&increment_cl,
+					 STARPU_RW, handle1,
+					 STARPU_RW, handle2,
+					 STARPU_RW, handle3,
+					 0);
+		STARPU_CHECK_RETURN_VALUE(ret, "starpu_task_insert");
+		ret = starpu_task_insert(&increment_cl,
+					 STARPU_RW, handle1,
+					 STARPU_RW, handle2,
+					 STARPU_RW, handle3,
+					 STARPU_RW, handle4,
+					 0);
+		STARPU_CHECK_RETURN_VALUE(ret, "starpu_task_insert");
 	}
 
 	ret = starpu_data_acquire(handle1, STARPU_R);
