@@ -1,6 +1,6 @@
 /* StarPU --- Runtime system for heterogeneous multicore architectures.
  *
- * Copyright (C) 2017-2021  Université de Bordeaux, CNRS (LaBRI UMR 5800), Inria
+ * Copyright (C) 2017-2025  University of Bordeaux, CNRS (LaBRI UMR 5800), Inria
  *
  * StarPU is free software; you can redistribute it and/or modify
  * it under the terms of the GNU Lesser General Public License as published by
@@ -71,10 +71,10 @@ struct variable_size_interface
 
 static struct starpu_data_interface_ops starpu_interface_variable_size_ops;
 
-static void register_variable_size(starpu_data_handle_t handle, unsigned home_node, void *data_interface)
+static void register_variable_size(starpu_data_handle_t handle, int home_node, void *data_interface)
 {
 	struct variable_size_interface *variable_size_interface = data_interface;
-	unsigned node;
+	int node;
 	for (node = 0; node < STARPU_MAXNODES; node++)
 	{
 		struct variable_size_interface *local_interface =
@@ -92,10 +92,6 @@ static void register_variable_size(starpu_data_handle_t handle, unsigned home_no
 
 void variable_size_data_register(starpu_data_handle_t *handleptr, unsigned x, unsigned y)
 {
-	if (starpu_interface_variable_size_ops.interfaceid == STARPU_UNKNOWN_INTERFACE_ID)
-	{
-		starpu_interface_variable_size_ops.interfaceid = starpu_data_interface_get_next_id();
-	}
 	struct variable_size_interface vsinterface =
 	{
 		.id = starpu_interface_variable_size_ops.interfaceid,
@@ -119,6 +115,12 @@ static size_t variable_size_get_size(starpu_data_handle_t handle)
 	return vsinterface->size;
 }
 
+static size_t variable_size_get_max_size(starpu_data_handle_t handle)
+{
+	(void)handle;
+	return FULLSIZE;
+}
+
 static uint32_t variable_size_footprint(starpu_data_handle_t handle)
 {
 	return starpu_hash_crc32c_be(variable_size_get_size(handle), 0);
@@ -164,6 +166,7 @@ static void free_variable_size_on_node(void *data_interface, unsigned node)
 	starpu_free_on_node(node, variable_interface->ptr, variable_interface->size);
 	if (node == STARPU_MAIN_RAM)
 		_starpu_simgrid_data_free(variable_interface->size);
+	variable_interface->ptr = 0;
 }
 
 static int variable_size_copy(void *src_interface, unsigned src_node, void *dst_interface, unsigned dst_node, void *async_data)
@@ -196,12 +199,14 @@ static struct starpu_data_interface_ops starpu_interface_variable_size_ops =
 	.free_data_on_node = free_variable_size_on_node,
 	.copy_methods = &variable_size_copy_data_methods,
 	.get_size = variable_size_get_size,
+	.get_max_size = variable_size_get_max_size,
 	.footprint = variable_size_footprint,
 	.compare = variable_size_compare,
 	.interfaceid = STARPU_UNKNOWN_INTERFACE_ID,
 	.interface_size = sizeof(struct variable_size_interface),
 	.display = display_variable_size,
 	.pack_data = NULL,
+	.peek_data = NULL,
 	.unpack_data = NULL,
 	.describe = describe_variable_size,
 
@@ -300,7 +305,12 @@ int main(void)
 	setenv("STARPU_DISK_SWAP_BACKEND", "unistd", 0);
 #endif
 
-	ret = starpu_init(NULL);
+	struct starpu_conf conf;
+	starpu_conf_init(&conf);
+	starpu_conf_noworker(&conf);
+	conf.ncpus = -1;
+
+	ret = starpu_init(&conf);
 	if (ret == -ENODEV) return STARPU_TEST_SKIPPED;
 	STARPU_CHECK_RETURN_VALUE(ret, "starpu_init");
 
@@ -310,8 +320,8 @@ int main(void)
 			variable_size_data_register(&handles[x][y], x, y);
 
 			ret = starpu_task_insert(&cl_init, STARPU_W, handles[x][y], 0);
-			if (ret == ENODEV)
-				goto enodev;
+			if (ret == -ENODEV) goto enodev;
+			STARPU_CHECK_RETURN_VALUE(ret, "starpu_task_insert");
 #ifdef STARPU_SIMGRID
 			starpu_sleep(0.0005);
 #endif
@@ -323,7 +333,10 @@ int main(void)
 	for (i = 0; i < N; i++)
 		for (x = i; x < N; x++)
 			for (y = x; y < N; y++)
-				starpu_task_insert(&cl, STARPU_RW, handles[x][y], STARPU_PRIORITY, (2*N-x-y), 0);
+			{
+				ret = starpu_task_insert(&cl, STARPU_RW, handles[x][y], STARPU_PRIORITY, (2*N-x-y), 0);
+				STARPU_CHECK_RETURN_VALUE(ret, "starpu_task_insert");
+			}
 
 	starpu_task_wait_for_all();
 
