@@ -1,6 +1,6 @@
 /* StarPU --- Runtime system for heterogeneous multicore architectures.
  *
- * Copyright (C) 2014-2021  Université de Bordeaux, CNRS (LaBRI UMR 5800), Inria
+ * Copyright (C) 2009-2025  University of Bordeaux, CNRS (LaBRI UMR 5800), Inria
  *
  * StarPU is free software; you can redistribute it and/or modify
  * it under the terms of the GNU Lesser General Public License as published by
@@ -28,8 +28,7 @@ int main(void)
 	return STARPU_TEST_SKIPPED;
 }
 #else
-int
-main (void)
+int main(void)
 {
 	int ret = starpu_omp_init();
 	if (ret == -EINVAL) return STARPU_TEST_SKIPPED;
