@@ -1,6 +1,6 @@
 /* StarPU --- Runtime system for heterogeneous multicore architectures.
  *
- * Copyright (C) 2014-2021  Université de Bordeaux, CNRS (LaBRI UMR 5800), Inria
+ * Copyright (C) 2009-2025  University of Bordeaux, CNRS (LaBRI UMR 5800), Inria
  *
  * StarPU is free software; you can redistribute it and/or modify
  * it under the terms of the GNU Lesser General Public License as published by
@@ -54,11 +54,13 @@ void locked_func(void)
 
 void master_g1(void *arg)
 {
+	(void)arg;
 	starpu_omp_init_lock(&omp_lock);
 }
 
 void master_g2(void *arg)
 {
+	(void)arg;
 	starpu_omp_destroy_lock(&omp_lock);
 }
 
@@ -93,8 +95,7 @@ void parallel_region_f(void *buffers[], void *args)
 	printf("[tid %p] task thread = %d -- parallel <--\n", (void *)tid, worker_id);
 }
 
-int
-main (void)
+int main(void)
 {
 	struct starpu_omp_parallel_region_attr attr;
 	pthread_t tid;
