@@ -1,9 +1,7 @@
 /* StarPU --- Runtime system for heterogeneous multicore architectures.
  *
- * Copyright (C) 2012,2013                                Inria
- * Copyright (C) 2011-2013,2017                           CNRS
- * Copyright (C) 2011,2013-2016                           Université de Bordeaux
- * Copyright (C) 2013                                     Thibaut Lambert
+ * Copyright (C) 2009-2025  University of Bordeaux, CNRS (LaBRI UMR 5800), Inria
+ * Copyright (C) 2013-2013  Thibaut Lambert
  *
  * StarPU is free software; you can redistribute it and/or modify
  * it under the terms of the GNU Lesser General Public License as published by
@@ -48,7 +46,7 @@ void codelet_null(void *descr[], void *_args)
 
 //	FPRINTF(stderr, "WORKERSIZE : %d\n", worker_size);
 
-	usleep(1000/worker_size);
+	starpu_usleep(1000./worker_size);
 #if 0
 	int id = starpu_worker_get_id();
 	int combined_id = starpu_combined_worker_get_id();
@@ -64,7 +62,7 @@ static struct starpu_codelet cl =
 	.cpu_funcs = {codelet_null},
 	.cpu_funcs_name = {"codelet_null"},
 	.cuda_funcs = {codelet_null},
-        .opencl_funcs = {codelet_null},
+	.opencl_funcs = {codelet_null},
 	.nbuffers = 1,
 	.modes = {STARPU_R}
 };
@@ -74,9 +72,9 @@ int main(void)
 {
 	int ret;
 
-        struct starpu_conf conf;
+	struct starpu_conf conf;
 	starpu_conf_init(&conf);
-        conf.sched_policy_name = "peager";
+	conf.sched_policy_name = "peager";
 
 	ret = starpu_init(&conf);
 	if (ret == -ENODEV) return STARPU_TEST_SKIPPED;
@@ -104,17 +102,17 @@ int main(void)
 	STARPU_CHECK_RETURN_VALUE(ret, "starpu_task_wait_for_all");
 
 	starpu_data_unregister(v_handle);
-	starpu_free(v);
+	starpu_free_noflag(v, VECTORSIZE*sizeof(unsigned));
 	starpu_shutdown();
 
 	return EXIT_SUCCESS;
 
 enodev:
 	starpu_data_unregister(v_handle);
-	starpu_free(v);
+	starpu_free_noflag(v, VECTORSIZE*sizeof(unsigned));
 	fprintf(stderr, "WARNING: No one can execute this task\n");
 	/* yes, we do not perform the computation but we did detect that no one
- 	 * could perform the kernel, so this is not an error from StarPU */
+	 * could perform the kernel, so this is not an error from StarPU */
 	starpu_shutdown();
 	return STARPU_TEST_SKIPPED;
 }
