@@ -1,7 +1,6 @@
 /* StarPU --- Runtime system for heterogeneous multicore architectures.
  *
- * Copyright (C) 2013,2015-2017                           CNRS
- * Copyright (C) 2013,2016                                Université de Bordeaux
+ * Copyright (C) 2009-2025  University of Bordeaux, CNRS (LaBRI UMR 5800), Inria
  *
  * StarPU is free software; you can redistribute it and/or modify
  * it under the terms of the GNU Lesser General Public License as published by
@@ -41,7 +40,7 @@ int _check_number(double val, int checknan)
 	strcpy(filename, tmp);
 
 #ifdef STARPU_HAVE_WINDOWS
-        _mktemp(filename);
+	_mktemp(filename);
 #else
 	{
 	     int id = mkstemp(filename);
@@ -92,7 +91,7 @@ int _check_number(double val, int checknan)
 	return pass?0:1;
 }
 
-int main(int argc, char **argv)
+int main(void)
 {
 	int ret1, ret2;
 	double nanvalue = nan("");
