@@ -1,7 +1,7 @@
 /* StarPU --- Runtime system for heterogeneous multicore architectures.
  *
- * Copyright (C) 2012-2021  Université de Bordeaux, CNRS (LaBRI UMR 5800), Inria
- * Copyright (C) 2013       Thibaut Lambert
+ * Copyright (C) 2012-2025  University of Bordeaux, CNRS (LaBRI UMR 5800), Inria
+ * Copyright (C) 2013-2013  Thibaut Lambert
  *
  * StarPU is free software; you can redistribute it and/or modify
  * it under the terms of the GNU Lesser General Public License as published by
@@ -27,14 +27,7 @@
 
 #define NTASKS           8
 
-void dummy(void *buffers[], void *args)
-{
-	(void) buffers;
-	(void) args;
-}
-
-static int
-run(struct starpu_sched_policy *p)
+static int run(struct starpu_sched_policy *p)
 {
 	int ret;
 	struct starpu_conf conf;
@@ -47,21 +40,12 @@ run(struct starpu_sched_policy *p)
 		exit(STARPU_TEST_SKIPPED);
 
 	struct starpu_task *tasks[NTASKS] = { NULL };
-	struct starpu_codelet cl =
-	{
-		.cpu_funcs    = {dummy},
-		.cpu_funcs_name = {"dummy"},
-		.cuda_funcs   = {dummy},
-		.opencl_funcs = {dummy},
-		.nbuffers     = 0
-	};
-
 	int i;
 	for (i = 0; i < NTASKS; i++)
 	{
 		struct starpu_task *task = starpu_task_create();
 		tasks[i] = task;
-		task->cl = &cl;
+		task->cl = &starpu_codelet_nop;
 		task->synchronous = 1;
 		task->destroy = 0;
 		ret = starpu_task_submit(task);
